
--
-- Definition for procedure SP_I_LOGBD
--
CREATE OR REPLACE PROCEDURE sp_i_LogBd(
		p_procediment IN LOGBD.PROCEDIMENT%TYPE,
		p_param_procediment IN LOGBD.PARAM_PROCEDIMENT%TYPE,
		p_hora_inici IN LOGBD.HORA_INICI%TYPE,
		p_hora_fi IN LOGBD.HORA_FI%TYPE,
		p_resultat IN LOGBD.RESULTAT%TYPE
		)
IS
BEGIN
	INSERT INTO LOGBD ("ID_LOGBD","PROCEDIMENT","PARAM_PROCEDIMENT","HORA_INICI","HORA_FI","RESULTAT")
	VALUES (s_LogBd.NEXTVAL,p_procediment,p_param_procediment,p_hora_inici,p_hora_fi,p_resultat);
	
	COMMIT;

  EXCEPTION
    WHEN OTHERS THEN
    DBMS_OUTPUT.PUT_LINE('Error insert LogBD procediment' || p_procediment);
END;
/

--
-- Definition for procedure SP_I_TIPUS_TITULACIO
--
CREATE OR REPLACE PROCEDURE sp_i_Tipus_Titulacio(
		p_descripcio IN TIPUS_TITULACIO.DESCRIPCIO%TYPE)
IS
    hora_inici logbd.hora_inici%TYPE;

BEGIN

  SELECT SYSDATE INTO hora_inici FROM DUAL;
  
  INSERT INTO TIPUS_TITULACIO ("ID_TIPUS_TITULACIO","DESCRIPCIO")
	VALUES (s_Tipus_Titulacio.NEXTVAL,p_descripcio);

  dbms_output.put_line('1 Tipus de Titulaci creat');
	
  sp_i_logbd('sp_i_Tipus_Titulacio',p_descripcio,hora_inici,sysdate,sqlerrm);
   
	COMMIT;
  
  EXCEPTION
  WHEN OTHERS THEN 
      ROLLBACK;
      DBMS_OUTPUT.PUT_LINE(sqlerrm);
      sp_i_logbd('sp_i_Tipus_Titulacio',p_descripcio,hora_inici,sysdate,sqlerrm);

END;
/

--
-- Definition for procedure SP_D_TIPUS_TITULACIO
--
CREATE OR REPLACE PROCEDURE sp_d_Tipus_Titulacio(
		p_id_tipus_titulacio IN TIPUS_TITULACIO.ID_TIPUS_TITULACIO%TYPE)
IS
    hora_inici logbd.hora_inici%TYPE;
    codi_Titulacio tipus_titulacio.id_tipus_titulacio%TYPE;
      
BEGIN
  SELECT SYSDATE INTO hora_inici FROM DUAL;
  

  SELECT id_Tipus_Titulacio INTO codi_Titulacio FROM Tipus_Titulacio 
  WHERE id_Tipus_Titulacio = p_id_tipus_titulacio;

  DELETE TIPUS_TITULACIO WHERE ID_TIPUS_TITULACIO = p_id_tipus_titulacio;
  DBMS_OUTPUT.PUT_LINE('Registre Tipus_Titulaci esborrat');
  sp_i_logbd('sp_d_Tipus_Titulacio',p_id_tipus_titulacio,hora_inici,sysdate,sqlerrm);
  COMMIT;

  EXCEPTION
     WHEN NO_DATA_FOUND THEN
       DBMS_OUTPUT.PUT_LINE('Registre no trobat');
       sp_i_logbd('sp_d_Tipus_Titulacio',p_id_tipus_titulacio,hora_inici,sysdate,sqlerrm);
     WHEN OTHERS THEN 
       ROLLBACK;
       DBMS_OUTPUT.PUT_LINE(sqlerrm);
       sp_i_logbd('sp_d_Tipus_Titulacio',p_id_tipus_titulacio,hora_inici,sysdate,sqlerrm);
END;
/

--
-- Definition for procedure SP_U_TIPUS_TITULACIO
--
CREATE OR REPLACE PROCEDURE sp_u_Tipus_Titulacio(
    p_id_tipus_titulacio IN TIPUS_TITULACIO.id_tipus_titulacio%TYPE,
		p_descripcio IN TIPUS_TITULACIO.DESCRIPCIO%TYPE)
IS
  hora_inici logbd.hora_inici%TYPE;
	codi_Titulacio tipus_titulacio.id_tipus_titulacio%TYPE;
  parametres logbd.param_procediment%TYPE;
   
BEGIN

  SELECT SYSDATE INTO hora_inici FROM DUAL;
  parametres:= p_descripcio || ';' || p_id_tipus_titulacio;

  SELECT id_Tipus_Titulacio INTO codi_Titulacio FROM Tipus_Titulacio 
  WHERE id_Tipus_Titulacio = p_id_tipus_titulacio;
      
  UPDATE tipus_titulacio SET descripcio = p_descripcio 
  WHERE id_tipus_titulacio = p_id_tipus_titulacio;

  dbms_output.put_line('Tipus de Titulaci actualitzat');
	sp_i_logbd('sp_u_Tipus_Titulacio',parametres,hora_inici,sysdate,sqlerrm);
  COMMIT;

  EXCEPTION
    WHEN NO_DATA_FOUND THEN
    DBMS_OUTPUT.PUT_LINE('Registre no trobat');
    sp_i_logbd('sp_u_Tipus_Titulacio',parametres,hora_inici,sysdate,sqlerrm);
END;
/

--
-- Definition for procedure SP_S_TIPUS_TITULACIO
--
CREATE OR REPLACE PROCEDURE sp_s_Tipus_Titulacio(
    p_id_tipus_titulacio IN TIPUS_TITULACIO.id_tipus_titulacio%TYPE)
IS
  hora_inici logbd.hora_inici%TYPE;
	codi_Titulacio tipus_titulacio.id_tipus_titulacio%TYPE;
  desc_Titulacio tipus_titulacio.descripcio%TYPE;
  
BEGIN
 
  SELECT SYSDATE INTO hora_inici FROM DUAL;
  
  SELECT id_tipus_titulacio,descripcio INTO codi_titulacio,desc_titulacio FROM Tipus_Titulacio 
  WHERE id_Tipus_Titulacio = p_id_tipus_titulacio;
  
  DBMS_OUTPUT.PUT_LINE(to_char(p_id_tipus_titulacio) || ' '  || ' ' || desc_titulacio);
  
  sp_i_logbd('sp_s_Tipus_Titulacio',p_id_tipus_titulacio,hora_inici,sysdate,sqlerrm);
  COMMIT;

  EXCEPTION
    WHEN NO_DATA_FOUND THEN
    DBMS_OUTPUT.PUT_LINE('Registre no trobat');
    sp_i_logbd('sp_s_Tipus_Titulacio',p_id_tipus_titulacio,hora_inici,sysdate,sqlerrm);
END;
/

--
-- Definition for procedure SP_S_BRANCA
--
CREATE OR REPLACE PROCEDURE sp_s_Branca(
    p_id_branca IN branca.DESCRIPCIO%TYPE)
IS
  hora_inici logbd.hora_inici%TYPE;
	codi_branca branca.id_branca%TYPE;
  desc_branca branca.descripcio%TYPE;
  
BEGIN
 
  SELECT SYSDATE INTO hora_inici FROM DUAL;
  
  SELECT id_branca,descripcio INTO codi_branca,desc_branca FROM branca
  WHERE id_branca = p_id_branca;
    
  DBMS_OUTPUT.PUT_LINE(to_char(p_id_branca) || ' '  || ' ' || desc_branca);
  
  sp_i_logbd('sp_s_Branca',p_id_branca,hora_inici,sysdate,sqlerrm);
  commit;
  EXCEPTION
    WHEN NO_DATA_FOUND THEN
    DBMS_OUTPUT.PUT_LINE('Registre no trobat');
    sp_i_logbd('sp_s_Branca',p_id_branca,hora_inici,sysdate,sqlerrm);
END;
/

--
-- Definition for procedure SP_I_BRANCA
--
CREATE OR REPLACE PROCEDURE sp_i_Branca(
		p_descripcio IN branca.descripcio%TYPE,
    p_id_tipus_titulacio IN branca.id_tipus_titulacio%TYPE)
IS
    hora_inici logbd.hora_inici%TYPE;
    parametres logbd.param_procediment%TYPE;
 
BEGIN

  SELECT SYSDATE INTO hora_inici FROM DUAL;
  
  parametres:= p_descripcio || ';' || p_id_tipus_titulacio;
  
  INSERT INTO BRANCA ("ID_BRANCA","DESCRIPCIO","ID_TIPUS_TITULACIO")
	VALUES (s_BRANCA.NEXTVAL,p_descripcio,p_id_tipus_titulacio);

  dbms_output.put_line('1 Branca creada');
  sp_i_logbd('sp_i_BRANCA',parametres,hora_inici,sysdate,sqlerrm);
   
	COMMIT;

  EXCEPTION
  WHEN OTHERS THEN 
      ROLLBACK;
      DBMS_OUTPUT.PUT_LINE(sqlerrm);
      sp_i_logbd('sp_i_Branca',parametres,hora_inici,sysdate,sqlerrm);
END;
/

--
-- Definition for procedure SP_U_BRANCA
--
CREATE OR REPLACE PROCEDURE sp_u_Branca(
    p_id_Branca IN Branca.DESCRIPCIO%TYPE,
		p_descripcio IN Branca.DESCRIPCIO%TYPE)
IS
  hora_inici logbd.hora_inici%TYPE;
	codi_Branca Branca.id_Branca%TYPE;
  parametres logbd.param_procediment%TYPE;
   
BEGIN

  SELECT SYSDATE INTO hora_inici FROM DUAL;
  parametres:= p_id_branca || ';' || p_descripcio;

  SELECT id_Branca INTO codi_branca FROM Branca 
  WHERE id_Branca = p_id_Branca;
      
  UPDATE Branca SET descripcio = p_descripcio 
  WHERE id_Branca = p_id_Branca;

  dbms_output.put_line('Branca actualitzada');
	sp_i_logbd('sp_u_Branca',parametres,hora_inici,sysdate,sqlerrm);
  COMMIT;

  EXCEPTION
    WHEN NO_DATA_FOUND THEN
    DBMS_OUTPUT.PUT_LINE('Registre no trobat');
    sp_i_logbd('sp_u_Branca',parametres,hora_inici,sysdate,sqlerrm);
END;
/

--
-- Definition for procedure SP_D_BRANCA
--
CREATE OR REPLACE PROCEDURE sp_d_Branca(
		p_id_Branca IN Branca.ID_Branca%TYPE)
IS
    hora_inici logbd.hora_inici%TYPE;
    codi_Branca Branca.id_Branca%TYPE;
     
BEGIN
  SELECT SYSDATE INTO hora_inici FROM DUAL;
  
  SELECT id_Branca INTO codi_branca FROM Branca 
  WHERE id_Branca = p_id_Branca;

  DELETE Branca WHERE ID_Branca = p_id_Branca;
  DBMS_OUTPUT.PUT_LINE('Registre Branca esborrat');
  sp_i_logbd('sp_d_Branca',p_id_Branca,hora_inici,sysdate,sqlerrm);
  COMMIT;
 
  EXCEPTION
     WHEN NO_DATA_FOUND THEN
       DBMS_OUTPUT.PUT_LINE('Registre no trobat');
       sp_i_logbd('sp_d_Branca',p_id_Branca,hora_inici,sysdate,sqlerrm);
     WHEN OTHERS THEN 
       ROLLBACK;
       DBMS_OUTPUT.PUT_LINE(sqlerrm);
       sp_i_logbd('sp_d_Branca',p_id_Branca,hora_inici,sysdate,sqlerrm);
END;
/

--
-- Definition for procedure SP_S_TITULACIO
--
CREATE OR REPLACE PROCEDURE sp_s_Titulacio(
    p_id_Titulacio IN Titulacio.DESCRIPCIO%TYPE)
IS
  hora_inici logbd.hora_inici%TYPE;
	codi_Titulacio Titulacio.id_Titulacio%TYPE;
  desc_Titulacio Titulacio.descripcio%TYPE;
  
BEGIN
 
  SELECT SYSDATE INTO hora_inici FROM DUAL;
  
  SELECT id_Titulacio,descripcio INTO codi_Titulacio,desc_Titulacio FROM Titulacio
  WHERE id_Titulacio = p_id_Titulacio;
    
  DBMS_OUTPUT.PUT_LINE(to_char(p_id_Titulacio) || ' '  || ' ' || desc_Titulacio);
  
  sp_i_logbd('sp_s_Titulacio',p_id_Titulacio,hora_inici,sysdate,sqlerrm);
  COMMIT;

  EXCEPTION
    WHEN NO_DATA_FOUND THEN
    DBMS_OUTPUT.PUT_LINE('Registre no trobat');
    sp_i_logbd('sp_s_Titulacio',p_id_Titulacio,hora_inici,sysdate,sqlerrm);
END;
/

--
-- Definition for procedure SP_I_TITULACIO
--
CREATE OR REPLACE PROCEDURE sp_i_Titulacio(
		p_descripcio IN Titulacio.descripcio%TYPE,
    p_id_branca IN Titulacio.id_branca%TYPE)
IS
    hora_inici logbd.hora_inici%TYPE;
    parametres logbd.param_procediment%TYPE;
 
BEGIN

  SELECT SYSDATE INTO hora_inici FROM DUAL;
  
  parametres:= p_descripcio || ';' || p_id_branca;
  
  INSERT INTO Titulacio ("ID_TITULACIO","DESCRIPCIO","ID_BRANCA")
	VALUES (s_Titulacio.NEXTVAL,p_descripcio,p_id_branca);

  dbms_output.put_line('1 Titulacio creada');
  sp_i_logbd('sp_i_Titulacio',parametres,hora_inici,sysdate,sqlerrm);
   
	COMMIT;

  EXCEPTION
  WHEN OTHERS THEN 
      ROLLBACK;
      DBMS_OUTPUT.PUT_LINE(sqlerrm);
      sp_i_logbd('sp_i_Titulacio',parametres,hora_inici,sysdate,sqlerrm);
END;
/

--
-- Definition for procedure SP_U_TITULACIO
--
CREATE OR REPLACE PROCEDURE sp_u_Titulacio(
    p_id_Titulacio IN Titulacio.DESCRIPCIO%TYPE,
		p_descripcio IN Titulacio.DESCRIPCIO%TYPE)
IS
  hora_inici logbd.hora_inici%TYPE;
	codi_Titulacio Titulacio.id_Titulacio%TYPE;
  parametres logbd.param_procediment%TYPE;
   
BEGIN

  SELECT SYSDATE INTO hora_inici FROM DUAL;
  parametres:= p_id_Titulacio || ';' || p_descripcio;

  SELECT id_Titulacio INTO codi_Titulacio FROM Titulacio 
  WHERE id_Titulacio = p_id_Titulacio;
      
  UPDATE Titulacio SET descripcio = p_descripcio 
  WHERE id_Titulacio = p_id_Titulacio;

  dbms_output.put_line('Titulacio actualitzada');
	sp_i_logbd('sp_u_Titulacio',parametres,hora_inici,sysdate,sqlerrm);
  COMMIT;

  EXCEPTION
    WHEN NO_DATA_FOUND THEN
    DBMS_OUTPUT.PUT_LINE('Registre no trobat');
    sp_i_logbd('sp_u_Titulacio',parametres,hora_inici,sysdate,sqlerrm);
END;
/

--
-- Definition for procedure SP_D_TITULACIO
--
CREATE OR REPLACE PROCEDURE sp_d_Titulacio(
		p_id_Titulacio IN Titulacio.ID_Titulacio%TYPE)
IS
    hora_inici logbd.hora_inici%TYPE;
    codi_Titulacio Titulacio.id_Titulacio%TYPE;
      
BEGIN
  SELECT SYSDATE INTO hora_inici FROM DUAL;
  
  SELECT id_Titulacio INTO codi_Titulacio FROM Titulacio 
  WHERE id_Titulacio = p_id_Titulacio;

  DELETE Titulacio WHERE ID_Titulacio = p_id_Titulacio;
  DBMS_OUTPUT.PUT_LINE('Registre Titulacio esborrat');
  sp_i_logbd('sp_d_Titulacio',p_id_Titulacio,hora_inici,sysdate,sqlerrm);
  COMMIT;

  EXCEPTION
     WHEN NO_DATA_FOUND THEN
       DBMS_OUTPUT.PUT_LINE('Registre no trobat');
       sp_i_logbd('sp_d_Titulacio',p_id_Titulacio,hora_inici,sysdate,sqlerrm);
     WHEN OTHERS THEN 
       ROLLBACK;
       DBMS_OUTPUT.PUT_LINE(sqlerrm);
       sp_i_logbd('sp_d_Titulacio',p_id_Titulacio,hora_inici,sysdate,sqlerrm);
END;
/

--
-- Definition for procedure SP_S_AREA_LABORAL
--
CREATE OR REPLACE PROCEDURE sp_s_Area_Laboral(
    p_id_Area_Laboral IN Area_Laboral.DESCRIPCIO%TYPE)
IS
  hora_inici logbd.hora_inici%TYPE;
	codi_Area_Laboral Area_Laboral.id_Area_Laboral%TYPE;
  desc_Area_Laboral Area_Laboral.descripcio%TYPE;
  
BEGIN

  SELECT SYSDATE INTO hora_inici FROM DUAL;
  
  SELECT id_Area_Laboral,descripcio INTO codi_area_laboral,desc_area_laboral FROM Area_Laboral 
  WHERE id_Area_Laboral = p_id_Area_Laboral;
  
  DBMS_OUTPUT.PUT_LINE(to_char(p_id_Area_Laboral) || ' '  || ' ' || desc_area_laboral);
  
  sp_i_logbd('sp_s_Area_Laboral',p_id_Area_Laboral,hora_inici,sysdate,sqlerrm);
  COMMIT;

  EXCEPTION
    WHEN NO_DATA_FOUND THEN
    DBMS_OUTPUT.PUT_LINE('Registre no trobat');
    sp_i_logbd('sp_s_Area_Laboral',p_id_Area_Laboral,hora_inici,sysdate,sqlerrm);
END;
/

--
-- Definition for procedure SP_I_AREA_LABORAL
--
CREATE OR REPLACE PROCEDURE sp_i_Area_Laboral(
		p_descripcio IN Area_Laboral.DESCRIPCIO%TYPE)
IS
    hora_inici logbd.hora_inici%TYPE;
 
BEGIN

  SELECT SYSDATE INTO hora_inici FROM DUAL;
  
  INSERT INTO Area_Laboral ("ID_AREA_LABORAL","DESCRIPCIO")
	VALUES (s_Area_Laboral.NEXTVAL,p_descripcio);

  dbms_output.put_line('1 rea Laboral Creada');
	
  sp_i_logbd('sp_i_Area_Laboral',p_descripcio,hora_inici,sysdate,sqlerrm);
   
	COMMIT;
END;
/

--
-- Definition for procedure SP_U_AREA_LABORAL
--
CREATE OR REPLACE PROCEDURE sp_u_Area_Laboral(
    p_id_Area_Laboral IN Area_Laboral.DESCRIPCIO%TYPE,
		p_descripcio IN Area_Laboral.DESCRIPCIO%TYPE)
IS
  hora_inici logbd.hora_inici%TYPE;
	codi_Area_Laboral Area_Laboral.id_Area_Laboral%TYPE;
  parametres logbd.param_procediment%TYPE;
   
BEGIN

  SELECT SYSDATE INTO hora_inici FROM DUAL;
  parametres:= p_descripcio || ';' || p_id_Area_Laboral;

  SELECT id_Area_Laboral INTO codi_area_laboral FROM Area_Laboral 
  WHERE id_Area_Laboral = p_id_Area_Laboral;
      
  UPDATE Area_Laboral SET descripcio = p_descripcio 
  WHERE id_Area_Laboral = p_id_Area_Laboral;

  dbms_output.put_line('Area Laboral actualitzada');
	sp_i_logbd('sp_u_Area_Laboral',parametres,hora_inici,sysdate,sqlerrm);
  COMMIT;

  EXCEPTION
    WHEN NO_DATA_FOUND THEN
    DBMS_OUTPUT.PUT_LINE('Registre no trobat');
    sp_i_logbd('sp_u_Area_Laboral',parametres,hora_inici,sysdate,sqlerrm);
END;
/

--
-- Definition for procedure SP_D_AREA_LABORAL
--
CREATE OR REPLACE PROCEDURE sp_d_Area_Laboral(
		p_id_Area_Laboral IN Area_Laboral.ID_Area_Laboral%TYPE)
IS
    hora_inici logbd.hora_inici%TYPE;
    codi_Area_Laboral Area_Laboral.id_Area_Laboral%TYPE;
     
BEGIN
  SELECT SYSDATE INTO hora_inici FROM DUAL;
  

  SELECT id_Area_Laboral INTO codi_area_laboral FROM Area_Laboral 
  WHERE id_Area_Laboral = p_id_Area_Laboral;

  DELETE Area_Laboral WHERE ID_Area_Laboral = p_id_Area_Laboral;
  DBMS_OUTPUT.PUT_LINE('Registre rea Laboral esborrat');
  sp_i_logbd('sp_d_Area_Laboral',p_id_Area_Laboral,hora_inici,sysdate,sqlerrm);
  COMMIT;
 
  EXCEPTION
     WHEN NO_DATA_FOUND THEN
       DBMS_OUTPUT.PUT_LINE('Registre no trobat');
       sp_i_logbd('sp_d_Area_Laboral',p_id_Area_Laboral,hora_inici,sysdate,sqlerrm);
     WHEN OTHERS THEN 
       ROLLBACK;
       DBMS_OUTPUT.PUT_LINE(sqlerrm);
       sp_i_logbd('sp_d_Area_Laboral',p_id_Area_Laboral,hora_inici,sysdate,sqlerrm);
END;
/

--
-- Definition for procedure SP_S_PERFIL
--
CREATE OR REPLACE PROCEDURE sp_s_Perfil(
    p_id_Perfil IN Perfil.DESCRIPCIO%TYPE)
IS
  hora_inici logbd.hora_inici%TYPE;
	codi_Perfil Perfil.id_Perfil%TYPE;
  desc_Perfil Perfil.descripcio%TYPE;
  
BEGIN
 
  SELECT SYSDATE INTO hora_inici FROM DUAL;
  
  SELECT id_Perfil,descripcio INTO codi_Perfil,desc_Perfil FROM Perfil
  WHERE id_Perfil = p_id_Perfil;
    
  DBMS_OUTPUT.PUT_LINE(to_char(p_id_Perfil) || ' '  || ' ' || desc_Perfil);
  
  sp_i_logbd('sp_s_Perfil',p_id_Perfil,hora_inici,sysdate,sqlerrm);
  COMMIT;

  EXCEPTION
    WHEN NO_DATA_FOUND THEN
    DBMS_OUTPUT.PUT_LINE('Registre no trobat');
    sp_i_logbd('sp_s_Perfil',p_id_Perfil,hora_inici,sysdate,sqlerrm);
END;
/

--
-- Definition for procedure SP_I_PERFIL
--
CREATE OR REPLACE PROCEDURE sp_i_Perfil(
		p_descripcio IN Perfil.descripcio%TYPE,
    p_id_area_laboral IN Perfil.id_area_laboral%TYPE)
IS
    hora_inici logbd.hora_inici%TYPE;
    parametres logbd.param_procediment%TYPE;
 
BEGIN
 
  SELECT SYSDATE INTO hora_inici FROM DUAL;
  
  parametres:= p_descripcio || ';' || p_id_area_laboral;
  
  INSERT INTO Perfil ("ID_PERFIL","DESCRIPCIO","ID_AREA_LABORAL")
	VALUES (s_Perfil.NEXTVAL,p_descripcio,p_id_area_laboral);

  dbms_output.put_line('1 Perfil creat');
  sp_i_logbd('sp_i_Perfil',parametres,hora_inici,sysdate,sqlerrm);
   
	COMMIT;

  EXCEPTION
  WHEN OTHERS THEN 
      ROLLBACK;
      DBMS_OUTPUT.PUT_LINE(sqlerrm);
      sp_i_logbd('sp_i_Perfil',parametres,hora_inici,sysdate,sqlerrm);
END;
/

--
-- Definition for procedure SP_U_PERFIL
--
CREATE OR REPLACE PROCEDURE sp_u_Perfil(
    p_id_Perfil IN Perfil.DESCRIPCIO%TYPE,
		p_descripcio IN Perfil.DESCRIPCIO%TYPE)
IS
  hora_inici logbd.hora_inici%TYPE;
	codi_Perfil Perfil.id_Perfil%TYPE;
  parametres logbd.param_procediment%TYPE;
   
BEGIN

  SELECT SYSDATE INTO hora_inici FROM DUAL;
  parametres:= p_id_Perfil || ';' || p_descripcio;

  SELECT id_Perfil INTO codi_Perfil FROM Perfil 
  WHERE id_Perfil = p_id_Perfil;
      
  UPDATE Perfil SET descripcio = p_descripcio 
  WHERE id_Perfil = p_id_Perfil;

  dbms_output.put_line('Perfil actualitzada');
	sp_i_logbd('sp_u_Perfil',parametres,hora_inici,sysdate,sqlerrm);
  COMMIT;

  EXCEPTION
    WHEN NO_DATA_FOUND THEN
    DBMS_OUTPUT.PUT_LINE('Registre no trobat');
    sp_i_logbd('sp_u_Perfil',parametres,hora_inici,sysdate,sqlerrm);
END;
/

--
-- Definition for procedure SP_D_PERFIL
--
CREATE OR REPLACE PROCEDURE sp_d_Perfil(
		p_id_Perfil IN Perfil.ID_Perfil%TYPE)
IS
    hora_inici logbd.hora_inici%TYPE;
    codi_Perfil Perfil.id_Perfil%TYPE;
      
BEGIN
  SELECT SYSDATE INTO hora_inici FROM DUAL;
  
  SELECT id_Perfil INTO codi_Perfil FROM Perfil 
  WHERE id_Perfil = p_id_Perfil;

  DELETE Perfil WHERE ID_Perfil = p_id_Perfil;
  DBMS_OUTPUT.PUT_LINE('Registre Perfil esborrat');
  sp_i_logbd('sp_d_Perfil',p_id_Perfil,hora_inici,sysdate,sqlerrm);
  COMMIT;

  EXCEPTION
     WHEN NO_DATA_FOUND THEN
       DBMS_OUTPUT.PUT_LINE('Registre no trobat');
       sp_i_logbd('sp_d_Perfil',p_id_Perfil,hora_inici,sysdate,sqlerrm);
     WHEN OTHERS THEN 
       ROLLBACK;
       DBMS_OUTPUT.PUT_LINE(sqlerrm);
       sp_i_logbd('sp_d_Perfil',p_id_Perfil,hora_inici,sysdate,sqlerrm);
END;
/

--
-- Definition for procedure SP_I_PERSONA
--
CREATE OR REPLACE PROCEDURE sp_i_Persona(
    p_tipus_persona IN persona.tipus_persona%TYPE,
    p_dni IN Persona.dni%TYPE,
    p_nom IN persona.nom%TYPE,
    p_cognom1 IN persona.cognom1%TYPE,
    p_cognom2 IN persona.cognom2%TYPE,
    p_nom_complet IN persona.nom_complet%TYPE,
    p_data_naixement IN persona.data_naixement%TYPE,
    p_adreca IN persona.adreca%TYPE,
    p_municipi IN persona.municipi%TYPE,
    p_provincia IN persona.provincia%TYPE,
    p_pais IN persona.pais%TYPE,
    p_email IN persona.email%TYPE,
    p_web IN persona.web%TYPE,
    p_telefon IN persona.telefon%TYPE)
IS
    hora_inici logbd.hora_inici%TYPE;
    parametres logbd.param_procediment%TYPE;
    v_id_persona persona.id_persona%TYPE;
 
BEGIN

  SELECT SYSDATE INTO hora_inici FROM DUAL;
  v_id_persona:=s_persona.nextval;

  parametres:= v_id_persona || ';' || p_tipus_persona || ';' || p_dni || ';' || p_nom || ';' || p_cognom1 || ';' || p_cognom2 || ';' || p_nom_complet || ';' || 
               p_data_naixement || ';' || p_adreca || ';' || p_municipi || ';' || p_provincia || ';' || p_pais || ';' || p_email || ';' || p_web || ';' || p_telefon;

  INSERT INTO Persona ("ID_PERSONA","TIPUS_PERSONA","DNI","NOM","COGNOM1","COGNOM2","NOM_COMPLET","DATA_NAIXEMENT","ADRECA","MUNICIPI","PROVINCIA","PAIS","EMAIL","WEB","TELEFON")
	VALUES (v_id_persona,p_tipus_persona,p_dni,p_nom,p_cognom1,p_cognom2,p_nom_complet,p_data_naixement,p_adreca,p_municipi,p_provincia,p_pais,p_email,p_web,p_telefon);

  dbms_output.put_line('1 Persona Creada');
	sp_i_logbd('sp_i_Persona',parametres,hora_inici,sysdate,sqlerrm);

  COMMIT;
  EXCEPTION
   WHEN OTHERS THEN 
      ROLLBACK;
      DBMS_OUTPUT.PUT_LINE(sqlerrm);
      sp_i_logbd('sp_i_Persona',parametres,hora_inici,sysdate,sqlerrm);
END;
/

--
-- Definition for procedure SP_S_PERSONA
--
CREATE OR REPLACE PROCEDURE sp_s_Persona(
    p_id_persona IN Persona.id_persona%TYPE)
IS
  hora_inici logbd.hora_inici%TYPE;
  id_persona_persona persona.id_persona%TYPE;
	dni_persona persona.dni%TYPE;
  tipus_persona_persona persona.tipus_persona%TYPE;
  nom_persona persona.nom%TYPE;
  cognom1_persona persona.cognom1%TYPE;
  cognom2_persona persona.cognom2%TYPE;
  data_naixement_persona persona.data_naixement%TYPE;
  nom_complet_persona persona.nom_complet%TYPE;
  adreca_persona persona.adreca%TYPE;
  municipi_persona persona.municipi%TYPE;
  provincia_persona persona.provincia%TYPE;
  pais_persona persona.pais%TYPE;
  email_persona persona.email%TYPE;
  web_persona persona.web%TYPE;
  telefon_persona persona.telefon%TYPE;
    
BEGIN

  SELECT SYSDATE INTO hora_inici FROM DUAL;
  
  
  --SELECT id_persona,tipus_persona,dni,cognom1,cognom2,nom_complet,adreca,municipi,provincia,pais,email,web,telefon 
  --INTO v_id_persona,tipus_persona_persona,dni_persona,cognom1_persona,cognom2_persona,nom_complet_persona,data_naixement_persona,adreca_persona,
  --     municipi_persona,provincia_persona,pais_persona,email_persona,web_persona,telefon_persona
  --FROM Persona 
  --WHERE id_persona = p_id_persona;

  SELECT id_persona, tipus_persona, dni, nom, cognom1,cognom2,nom_complet, data_naixement, adreca, municipi,
         provincia, pais, email, web, telefon 
  INTO id_persona_persona,tipus_persona_persona,dni_persona,nom_persona,cognom1_persona,cognom2_persona,nom_complet_persona,
       data_naixement_persona, adreca_persona,municipi_persona,provincia_persona,pais_persona,email_persona,web_persona,telefon_persona
  FROM persona
  WHERE id_persona = p_id_persona;

 
  DBMS_OUTPUT.PUT_LINE('ID:' || p_id_persona || ' ' || 'TIPUS:' || tipus_persona_persona || ' ' || 'DNI: ' || dni_persona || ' ' || 'NOM:' || nom_persona || ' ' || 'COGNOM1:' || cognom1_persona || ' ' || 'COGNOM2:' || cognom2_persona || ' ' || 'NOM COMPLET:' || nom_complet_persona || ';' || 
                       'DATA NAIXEMENT:' || data_naixement_persona || ' ' || 'ADREA:' || adreca_persona || ';' || 'MUNICIPI:' || municipi_persona || ' ' || 'PROVINCIA:' || provincia_persona || ' ' || 'PAIS:' || pais_persona || ' ' || 'EMAIL:' || email_persona || ' ' || 'WEB:' || web_persona || ' '
                       || 'TELEFON:' || telefon_persona);

  sp_i_logbd('sp_s_Persona',p_id_persona,hora_inici,sysdate,sqlerrm);
  COMMIT;

  EXCEPTION
    WHEN NO_DATA_FOUND THEN
    DBMS_OUTPUT.PUT_LINE('Registre no trobat');
    sp_i_logbd('sp_s_Persona',p_id_persona,hora_inici,sysdate,sqlerrm);
END;
/

--
-- Definition for procedure SP_D_PERSONA
--
CREATE OR REPLACE PROCEDURE sp_d_Persona(
		p_id_persona IN persona.id_persona%TYPE)
IS
    hora_inici logbd.hora_inici%TYPE;
    v_id_persona Persona.id_persona%TYPE;
      
BEGIN
  SELECT SYSDATE INTO hora_inici FROM DUAL;
  
  SELECT id_persona INTO v_id_persona FROM Persona 
  WHERE id_persona = p_id_persona;

  DELETE Persona WHERE id_persona = p_id_persona;
  DBMS_OUTPUT.PUT_LINE('Registre Persona esborrat');
  sp_i_logbd('sp_d_Persona',p_id_persona,hora_inici,sysdate,sqlerrm);
  COMMIT;

  EXCEPTION
     WHEN NO_DATA_FOUND THEN
       DBMS_OUTPUT.PUT_LINE('Registre no trobat');
       sp_i_logbd('sp_d_Persona',p_id_persona,hora_inici,sysdate,sqlerrm);
     WHEN OTHERS THEN 
       ROLLBACK;
       DBMS_OUTPUT.PUT_LINE(sqlerrm);
       sp_i_logbd('sp_d_Persona',p_id_persona,hora_inici,sysdate,sqlerrm);
END;
/

--
-- Definition for procedure SP_U_PERSONA
--
CREATE OR REPLACE PROCEDURE sp_u_Persona(
    p_id_persona IN persona.id_persona%TYPE,
    p_tipus_persona IN persona.tipus_persona%TYPE,
    p_dni IN Persona.dni%TYPE,
    p_nom IN persona.nom%TYPE,
    p_cognom1 IN persona.cognom1%TYPE,
    p_cognom2 IN persona.cognom2%TYPE,
    p_nom_complet IN persona.nom_complet%TYPE,
    p_data_naixement IN persona.data_naixement%TYPE,
    p_adreca IN persona.adreca%TYPE,
    p_municipi IN persona.municipi%TYPE,
    p_provincia IN persona.provincia%TYPE,
    p_pais IN persona.pais%TYPE,
    p_email IN persona.email%TYPE,
    p_web IN persona.web%TYPE,
    p_telefon IN persona.telefon%TYPE)
    
IS
  hora_inici logbd.hora_inici%TYPE;
	id_persona_persona Persona.id_persona%TYPE;
  rec_persona persona%ROWTYPE;
  parametres logbd.param_procediment%TYPE;
  
BEGIN

   SELECT SYSDATE INTO hora_inici FROM DUAL;
   parametres:= p_id_persona || ';' || p_tipus_persona || ';' || p_dni || ';' || p_nom || ';' || p_cognom1 || ';' || p_cognom2 || ';' || p_nom_complet || ';' || p_data_naixement || ';'
   || p_adreca || ';' || p_municipi || ';' || p_provincia || ';' || p_pais || ';' || p_email || ';' || p_web || ';' || p_telefon;


   SELECT * INTO rec_persona FROM persona 
   WHERE id_persona = p_id_persona;
      
   IF p_dni IS NOT NULL THEN rec_persona.dni:= p_dni;
   END IF;
   IF p_tipus_persona IS NOT NULL THEN rec_persona.tipus_persona:= p_tipus_persona;
   END IF;
   IF p_nom IS NOT NULL THEN rec_persona.nom:= p_nom;
   END IF;
   IF p_cognom1 IS NOT NULL THEN rec_persona.cognom1:= p_cognom1;
   END IF;
   IF p_cognom2 IS NOT NULL THEN rec_persona.cognom2:= p_cognom2;
   END IF;
   IF p_data_naixement IS NOT NULL THEN rec_persona.data_naixement:= p_data_naixement;
   END IF;
   IF p_nom_complet IS NOT NULL THEN rec_persona.nom_complet:= p_nom_complet;
   END IF;
   IF p_adreca IS NOT NULL THEN rec_persona.adreca:= p_adreca;
   END IF;
   IF p_municipi IS NOT NULL THEN rec_persona.municipi:= p_municipi;
   END IF;
   IF p_provincia IS NOT NULL THEN rec_persona.provincia:= p_provincia;
   END IF;
   IF p_pais IS NOT NULL THEN rec_persona.pais:= p_pais;
   END IF;
   IF p_email IS NOT NULL THEN rec_persona.email:= p_email;
   END IF;
   IF p_web IS NOT NULL THEN rec_persona.web:= p_web;
   END IF;
   IF p_telefon IS NOT NULL THEN rec_persona.telefon:= p_telefon;
   END IF;
   
   UPDATE Persona SET ROW = rec_persona
   WHERE id_persona = p_id_persona;
  
   dbms_output.put_line('Persona actualitzada');
   sp_i_logbd('sp_u_Persona',parametres,hora_inici,sysdate,sqlerrm);
   COMMIT;
  
   EXCEPTION
      WHEN NO_DATA_FOUND THEN
         DBMS_OUTPUT.PUT_LINE('Registre no trobat');
         sp_i_logbd('sp_u_Persona',parametres,hora_inici,sysdate,sqlerrm);
      WHEN OTHERS THEN 
         ROLLBACK;
         DBMS_OUTPUT.PUT_LINE(sqlerrm);
         sp_i_logbd('sp_u_Persona',parametres,hora_inici,sysdate,sqlerrm);
END;
/

--
-- Definition for procedure SP_I_SOLICITUD
--
CREATE OR REPLACE PROCEDURE sp_i_Solicitud(
    p_data IN Solicitud.data%TYPE,
    p_hores IN Solicitud.hores%TYPE,
    p_salari IN Solicitud.salari%TYPE,
    p_experiencia IN Solicitud.experiencia%TYPE,
    p_periodicitat IN Solicitud.periodicitat%TYPE,
    p_tipus_jornada IN Solicitud.tipus_jornada%TYPE,
    p_id_persona IN Solicitud.id_persona%TYPE,
    p_id_perfil IN Solicitud.id_perfil%TYPE)
IS
    hora_inici logbd.hora_inici%TYPE;
    parametres logbd.param_procediment%TYPE;

BEGIN

  SELECT SYSDATE INTO hora_inici FROM DUAL;
  
  parametres:= p_data || ';' || p_hores || ';' || p_salari || ';' || p_experiencia || ';' || p_periodicitat || ';'
  || p_tipus_jornada || ';' || p_id_persona || ';' || p_id_perfil;

  INSERT INTO Solicitud ("ID_SOLICITUD","DATA","HORES","SALARI","EXPERIENCIA","PERIODICITAT","TIPUS_JORNADA","ID_PERSONA","ID_PERFIL")
	VALUES (s_Solicitud.NEXTVAL,p_data,p_hores,p_salari,p_experiencia,p_periodicitat,p_tipus_jornada,p_id_persona,p_id_perfil);

  dbms_output.put_line('1 Solicitud Creada');
	sp_i_logbd('sp_i_Solicitud',parametres,hora_inici,sysdate,sqlerrm);

  COMMIT;
  EXCEPTION
   WHEN OTHERS THEN 
      ROLLBACK;
      DBMS_OUTPUT.PUT_LINE(sqlerrm);
      sp_i_logbd('sp_i_Solicitud',parametres,hora_inici,sysdate,sqlerrm);
END;
/

--
-- Definition for procedure SP_S_SOLICITUD
--
CREATE OR REPLACE PROCEDURE sp_s_Solicitud(
    p_id_solicitud IN Solicitud.id_solicitud%TYPE)
IS
  hora_inici logbd.hora_inici%TYPE;
  data_solicitud solicitud.data%TYPE;
  hores_solicitud solicitud.hores%TYPE;
  salari_solicitud solicitud.salari%TYPE;
  experiencia_solicitud solicitud.experiencia%TYPE;
  periodicitat_solicitud solicitud.periodicitat%TYPE;
  tipus_jornada_solicitud solicitud.tipus_jornada%TYPE;
  p_id_persona_solicitud solicitud.id_persona%TYPE;
  id_perfil_solicitud solicitud.id_perfil%TYPE;
  rec_solicitud solicitud%ROWTYPE;
  
  parametres logbd.param_procediment%TYPE;
	 
BEGIN
 
  SELECT SYSDATE INTO hora_inici FROM DUAL;

  SELECT * INTO rec_solicitud FROM solicitud
  WHERE id_solicitud = p_id_solicitud;

  DBMS_OUTPUT.PUT_LINE('ID SOLICITUD:' || rec_solicitud.id_solicitud || ' ' || 'DATA:' || rec_solicitud.data || ' ' || 'HORES:' || rec_solicitud.hores || ' ' || 'SALARI:' || rec_solicitud.salari || ' ' ||
                       'EXPERIENCIA:' || rec_solicitud.experiencia || ' ' || 'PERIODICITAT:' || rec_solicitud.periodicitat || ' ' || 'TIPUS JORNADA:' || rec_solicitud.tipus_jornada || ' ' ||
                       'ID PERSONA:' || rec_solicitud.id_persona || ' ' || 'PERFIL:' || rec_solicitud.id_perfil);

  sp_i_logbd('sp_s_Solicitud',p_id_solicitud,hora_inici,sysdate,sqlerrm);
  COMMIT;

  EXCEPTION
    WHEN NO_DATA_FOUND THEN
    DBMS_OUTPUT.PUT_LINE('Registre no trobat');
    sp_i_logbd('sp_s_Solicitud',p_id_solicitud,hora_inici,sysdate,sqlerrm);
END;
/

--
-- Definition for procedure SP_D_SOLICITUD
--
CREATE OR REPLACE PROCEDURE sp_d_Solicitud(
		p_id_solicitud IN Solicitud.id_solicitud%TYPE)
IS
    hora_inici logbd.hora_inici%TYPE;
    id_Solicitud Solicitud.id_solicitud%TYPE;
     
BEGIN
  SELECT SYSDATE INTO hora_inici FROM DUAL;
  
  SELECT id_solicitud INTO id_solicitud FROM Solicitud 
  WHERE id_solicitud = p_id_solicitud;

  DELETE Solicitud WHERE id_solicitud = p_id_solicitud;
  DBMS_OUTPUT.PUT_LINE('Registre Solicitud esborrat');
  sp_i_logbd('sp_d_Solicitud',p_id_solicitud,hora_inici,sysdate,sqlerrm);
  COMMIT;

  EXCEPTION
     WHEN NO_DATA_FOUND THEN
       DBMS_OUTPUT.PUT_LINE('Registre no trobat');
       sp_i_logbd('sp_d_Solicitud',p_id_solicitud,hora_inici,sysdate,sqlerrm);
     WHEN OTHERS THEN 
       ROLLBACK;
       DBMS_OUTPUT.PUT_LINE(sqlerrm);
       sp_i_logbd('sp_d_Solicitud',p_id_solicitud,hora_inici,sysdate,sqlerrm);
END;
/

--
-- Definition for procedure SP_U_SOLICITUD
--
CREATE OR REPLACE PROCEDURE sp_u_Solicitud(
    p_id_solicitud IN solicitud.id_solicitud%TYPE,
    p_data IN Solicitud.data%TYPE,
    p_hores IN Solicitud.hores%TYPE,
    p_salari IN Solicitud.salari%TYPE,
    p_experiencia IN Solicitud.experiencia%TYPE,
    p_periodicitat IN Solicitud.periodicitat%TYPE,
    p_tipus_jornada IN Solicitud.tipus_jornada%TYPE,
    p_id_persona IN Solicitud.id_persona%TYPE,
    p_id_perfil IN Solicitud.id_perfil%TYPE)
    
IS
  hora_inici logbd.hora_inici%TYPE;
	rec_Solicitud Solicitud%ROWTYPE;
  parametres logbd.param_procediment%TYPE;
  
BEGIN

   SELECT SYSDATE INTO hora_inici FROM DUAL;
   parametres:= p_id_solicitud || ';' || p_data || ';' || p_hores || ';' || p_salari || ';' || p_experiencia || ';' || p_periodicitat || ';' || 
                p_tipus_jornada || ';' || p_id_persona || ';' || p_id_perfil;

   SELECT * INTO rec_Solicitud FROM Solicitud 
   WHERE id_solicitud = p_id_solicitud;
      
   IF p_data IS NOT NULL THEN rec_Solicitud.data:= p_data;
   END IF;
   IF p_hores IS NOT NULL THEN rec_Solicitud.hores:= p_hores;
   END IF;
   IF p_salari IS NOT NULL THEN rec_Solicitud.salari:= p_salari;
   END IF;
   IF p_experiencia IS NOT NULL THEN rec_Solicitud.experiencia:= p_experiencia;
   END IF;
   IF p_periodicitat IS NOT NULL THEN rec_Solicitud.periodicitat:= p_periodicitat;
   END IF;
   IF p_tipus_jornada IS NOT NULL THEN rec_Solicitud.tipus_jornada:= p_tipus_jornada;
   END IF;
   IF p_id_persona IS NOT NULL THEN rec_Solicitud.id_persona:= p_id_persona;
   END IF;
   IF p_id_perfil IS NOT NULL THEN rec_Solicitud.id_perfil:= p_id_perfil;
   END IF;
   
   UPDATE Solicitud SET ROW = rec_Solicitud
   WHERE id_solicitud = p_id_solicitud;
  
   dbms_output.put_line('Solicitud actualitzada');
   sp_i_logbd('sp_u_Solicitud',parametres,hora_inici,sysdate,sqlerrm);
   COMMIT;
  
   EXCEPTION
      WHEN NO_DATA_FOUND THEN
         DBMS_OUTPUT.PUT_LINE('Registre no trobat');
         sp_i_logbd('sp_u_Solicitud',parametres,hora_inici,sysdate,sqlerrm);
      WHEN OTHERS THEN 
         ROLLBACK;
         DBMS_OUTPUT.PUT_LINE(sqlerrm);
         sp_i_logbd('sp_u_Solicitud',parametres,hora_inici,sysdate,sqlerrm);
END;
/

--
-- Definition for procedure SP_I_OFERTA
--
CREATE OR REPLACE PROCEDURE sp_i_Oferta(
   p_num_places IN oferta.num_places%TYPE,
   p_prioritat IN oferta.prioritat%TYPE,
   p_coneix_informatics IN oferta.coneix_informatics%TYPE,
   p_data_oferta_coberta IN oferta.data_oferta_coberta%TYPE,
   p_id_solicitud IN oferta.id_solicitud%TYPE,
   p_id_titulacio IN oferta.id_titulacio%TYPE)
IS
    id_oferta_nextval oferta.id_oferta%TYPE;
    hora_inici logbd.hora_inici%TYPE;
    parametres logbd.param_procediment%TYPE;
 
BEGIN

  SELECT SYSDATE INTO hora_inici FROM DUAL;
  
  id_oferta_nextval:= s_Oferta.nextval;
  parametres:= id_oferta_nextval || ';' || p_num_places || ';' || p_prioritat || ';' || p_coneix_informatics || ';' || p_data_oferta_coberta || ';' ||
               p_id_solicitud || ';' || p_id_titulacio;

  INSERT INTO Oferta ("ID_OFERTA","NUM_PLACES","PRIORITAT","CONEIX_INFORMATICS","DATA_OFERTA_COBERTA","ID_SOLICITUD","ID_TITULACIO")
	VALUES (id_oferta_nextval,p_num_places,p_prioritat,p_coneix_informatics,p_data_oferta_coberta,p_id_solicitud,p_id_titulacio);

  dbms_output.put_line('1 Oferta Creada');
	sp_i_logbd('sp_i_Oferta',parametres,hora_inici,sysdate,sqlerrm);

  COMMIT;
  EXCEPTION
   WHEN OTHERS THEN 
      ROLLBACK;
      DBMS_OUTPUT.PUT_LINE(sqlerrm);
      sp_i_logbd('sp_i_Oferta',parametres,hora_inici,sysdate,sqlerrm);
END;
/

--
-- Definition for procedure SP_S_OFERTA
--
CREATE OR REPLACE PROCEDURE sp_s_Oferta(
    p_id_Oferta IN Oferta.id_Oferta%TYPE)
IS
  hora_inici logbd.hora_inici%TYPE;
  id_oferta oferta.id_oferta%TYPE;
  num_places oferta.num_places%TYPE;
  prioritat oferta.prioritat%TYPE;
  coneix_informatics oferta.coneix_informatics%TYPE;
  data_oferta_coberta oferta.data_oferta_coberta%TYPE;
  id_solicitud oferta.id_solicitud%TYPE;
  id_titulacio oferta.id_titulacio%TYPE;
  rec_Oferta Oferta%ROWTYPE;
  
  parametres logbd.param_procediment%TYPE;
	  
BEGIN
 
  SELECT SYSDATE INTO hora_inici FROM DUAL;

  SELECT * INTO rec_Oferta FROM Oferta
  WHERE id_Oferta = p_id_Oferta;

  DBMS_OUTPUT.PUT_LINE('ID Oferta:' || rec_Oferta.id_Oferta || ' ' || 'NUM.PLACES:' || rec_oferta.num_places || ' ' || 'PRIORITAT:' || rec_Oferta.prioritat || ' ' || 'CONEIXEM.INF:' ||
                        rec_Oferta.coneix_informatics || ' ' || 'COBERTA:' || rec_Oferta.data_oferta_coberta || ' ' || 'SOLLICITUD:' || rec_Oferta.id_solicitud || ' ' || 'TITULACI:' || rec_Oferta.id_titulacio);
  sp_i_logbd('sp_s_Oferta',p_id_Oferta,hora_inici,sysdate,sqlerrm);
  COMMIT;

  EXCEPTION
    WHEN NO_DATA_FOUND THEN
    DBMS_OUTPUT.PUT_LINE('Registre no trobat');
    sp_i_logbd('sp_s_Oferta',p_id_Oferta,hora_inici,sysdate,sqlerrm);
END;
/

--
-- Definition for procedure SP_D_OFERTA
--
CREATE OR REPLACE PROCEDURE sp_d_Oferta(
		p_id_Oferta IN Oferta.id_Oferta%TYPE)
IS
    hora_inici logbd.hora_inici%TYPE;
    id_Oferta Oferta.id_oferta%TYPE;
     
BEGIN
  SELECT SYSDATE INTO hora_inici FROM DUAL;
  
  SELECT id_Oferta INTO id_Oferta FROM Oferta 
  WHERE id_Oferta = p_id_Oferta;

  DELETE Oferta WHERE id_Oferta = p_id_Oferta;
  DBMS_OUTPUT.PUT_LINE('Registre Oferta esborrat');
  sp_i_logbd('sp_d_Oferta',p_id_Oferta,hora_inici,sysdate,sqlerrm);
  COMMIT;
 
  EXCEPTION
     WHEN NO_DATA_FOUND THEN
       DBMS_OUTPUT.PUT_LINE('Registre no trobat');
       sp_i_logbd('sp_d_Oferta',p_id_Oferta,hora_inici,sysdate,sqlerrm);
     WHEN OTHERS THEN 
       ROLLBACK;
       DBMS_OUTPUT.PUT_LINE(sqlerrm);
       sp_i_logbd('sp_d_Oferta',p_id_Oferta,hora_inici,sysdate,sqlerrm);
END;
/

--
-- Definition for procedure SP_U_OFERTA
--
CREATE OR REPLACE PROCEDURE sp_u_Oferta(
    p_id_Oferta IN Oferta.id_Oferta%TYPE,
    p_num_places IN oferta.num_places%TYPE,
    p_prioritat IN oferta.prioritat%TYPE,
    p_coneix_informatics IN oferta.coneix_informatics%TYPE,
    p_data_oferta_coberta IN oferta.data_oferta_coberta%TYPE,
    p_id_solicitud IN oferta.id_solicitud%TYPE,
    p_id_titulacio IN oferta.id_titulacio%TYPE)
     
IS
  hora_inici logbd.hora_inici%TYPE;
	rec_Oferta Oferta%ROWTYPE;
  parametres logbd.param_procediment%TYPE;
  
BEGIN

   SELECT SYSDATE INTO hora_inici FROM DUAL;

   parametres:= p_id_oferta || ';' || p_num_places || ';' || p_prioritat || ';' || p_coneix_informatics || ';' || p_data_oferta_coberta || ';' ||
               p_id_solicitud || ';' || p_id_titulacio;

   SELECT * INTO rec_Oferta FROM Oferta 
   WHERE id_Oferta = p_id_Oferta;
      
   IF p_num_places IS NOT NULL THEN rec_Oferta.num_places:= p_num_places;
   END IF;
   IF p_prioritat IS NOT NULL THEN rec_Oferta.prioritat:= p_prioritat;
   END IF;
   IF p_coneix_informatics IS NOT NULL THEN rec_Oferta.coneix_informatics:= p_coneix_informatics;
   END IF;
   IF p_data_oferta_coberta IS NOT NULL THEN rec_Oferta.data_oferta_coberta:= p_data_oferta_coberta;
   END IF;
   IF p_id_solicitud IS NOT NULL THEN rec_Oferta.id_solicitud:= p_id_solicitud;
   END IF;
   IF p_id_titulacio IS NOT NULL THEN rec_Oferta.id_titulacio:= p_id_titulacio;
   END IF;
   
   UPDATE Oferta SET ROW = rec_Oferta
   WHERE id_Oferta = p_id_Oferta;
  
   dbms_output.put_line('Oferta actualitzada');
   sp_i_logbd('sp_u_Oferta',parametres,hora_inici,sysdate,sqlerrm);
   COMMIT;
  
   EXCEPTION
      WHEN NO_DATA_FOUND THEN
         DBMS_OUTPUT.PUT_LINE('Registre no trobat');
         sp_i_logbd('sp_u_Oferta',parametres,hora_inici,sysdate,sqlerrm);
      WHEN OTHERS THEN 
         ROLLBACK;
         DBMS_OUTPUT.PUT_LINE(sqlerrm);
         sp_i_logbd('sp_u_Oferta',parametres,hora_inici,sysdate,sqlerrm);
END;
/

--
-- Definition for procedure SP_I_DEMANDA
--
CREATE OR REPLACE PROCEDURE sp_i_Demanda(
		p_id_solicitud IN demanda.id_solicitud%TYPE)
IS
    hora_inici logbd.hora_inici%TYPE;
    parametres logbd.param_procediment%TYPE;
    s_id_demanda demanda.id_demanda%TYPE;
     
BEGIN

  SELECT SYSDATE INTO hora_inici FROM DUAL;
  
  s_id_demanda:= s_Demanda.nextval;
  parametres:=s_id_demanda || p_id_solicitud;
  
  INSERT INTO Demanda ("ID_DEMANDA","ID_SOLICITUD")
	VALUES (s_id_demanda,p_id_solicitud);

  dbms_output.put_line('1 Demanda creada');
  sp_i_logbd('sp_i_Demanda',parametres,hora_inici,sysdate,sqlerrm);
   
	COMMIT;

  EXCEPTION
  WHEN OTHERS THEN 
      ROLLBACK;
      DBMS_OUTPUT.PUT_LINE(sqlerrm);
      sp_i_logbd('sp_i_Demanda',parametres,hora_inici,sysdate,sqlerrm);
END;
/

--
-- Definition for procedure SP_S_DEMANDA
--
CREATE OR REPLACE PROCEDURE sp_s_Demanda(
    p_id_demanda IN Demanda.id_demanda%TYPE)
IS
  hora_inici logbd.hora_inici%TYPE;
	rec_demanda demanda%ROWTYPE;
  
BEGIN

  SELECT SYSDATE INTO hora_inici FROM DUAL;
  
  SELECT * INTO rec_demanda FROM Demanda
  WHERE id_Demanda = p_id_Demanda;
    
  DBMS_OUTPUT.PUT_LINE('ID.DEMANDA: ' || rec_demanda.id_demanda || ' '  || 'ID_SOLLICITUD: '  || rec_demanda.id_solicitud);
  
  sp_i_logbd('sp_s_Demanda',p_id_Demanda,hora_inici,sysdate,sqlerrm);
  COMMIT;
 
  EXCEPTION
    WHEN NO_DATA_FOUND THEN
    DBMS_OUTPUT.PUT_LINE('Registre no trobat');
    sp_i_logbd('sp_s_Demanda',p_id_Demanda,hora_inici,sysdate,sqlerrm);
END;
/

--
-- Definition for procedure SP_D_DEMANDA
--
CREATE OR REPLACE PROCEDURE sp_d_Demanda(
		p_id_Demanda IN Demanda.ID_Demanda%TYPE)
IS
    hora_inici logbd.hora_inici%TYPE;
    codi_Demanda Demanda.id_Demanda%TYPE;
     
BEGIN
  SELECT SYSDATE INTO hora_inici FROM DUAL;
  
  SELECT id_Demanda INTO codi_Demanda FROM Demanda 
  WHERE id_Demanda = p_id_Demanda;

  DELETE Demanda WHERE ID_Demanda = p_id_Demanda;
  DBMS_OUTPUT.PUT_LINE('Registre Demanda esborrat');
  sp_i_logbd('sp_d_Demanda',p_id_Demanda,hora_inici,sysdate,sqlerrm);
  COMMIT;
 
  EXCEPTION
     WHEN NO_DATA_FOUND THEN
       DBMS_OUTPUT.PUT_LINE('Registre no trobat');
       sp_i_logbd('sp_d_Demanda',p_id_Demanda,hora_inici,sysdate,sqlerrm);
     WHEN OTHERS THEN 
       ROLLBACK;
       DBMS_OUTPUT.PUT_LINE(sqlerrm);
       sp_i_logbd('sp_d_Demanda',p_id_Demanda,hora_inici,sysdate,sqlerrm);
END;
/

--
-- Definition for procedure SP_U_DEMANDA
--
CREATE OR REPLACE PROCEDURE sp_u_Demanda(
    p_id_Demanda IN demanda.id_demanda%TYPE,
		p_id_Solicitud IN demanda.id_solicitud%TYPE)
IS
  hora_inici logbd.hora_inici%TYPE;
	codi_Demanda Demanda.id_Demanda%TYPE;
  parametres logbd.param_procediment%TYPE;
   
BEGIN

  SELECT SYSDATE INTO hora_inici FROM DUAL;
  parametres:= p_id_Demanda || ';' || p_id_solicitud;

  SELECT id_Demanda INTO codi_Demanda FROM Demanda 
  WHERE id_Demanda = p_id_Demanda;
      
  UPDATE Demanda SET id_solicitud = p_id_solicitud
  WHERE id_Demanda = p_id_Demanda;

  dbms_output.put_line('Demanda actualitzada');
	sp_i_logbd('sp_u_Demanda',parametres,hora_inici,sysdate,sqlerrm);
  COMMIT;

  EXCEPTION
    WHEN NO_DATA_FOUND THEN
    DBMS_OUTPUT.PUT_LINE('Registre no trobat');
    sp_i_logbd('sp_u_Demanda',parametres,hora_inici,sysdate,sqlerrm);
    WHEN OTHERS THEN 
       ROLLBACK;
       DBMS_OUTPUT.PUT_LINE(sqlerrm);
       sp_i_logbd('sp_u_Demanda',parametres,hora_inici,sysdate,sqlerrm);
END;
/

--
-- Definition for procedure SP_I_ENTREVISTA
--
CREATE OR REPLACE PROCEDURE sp_i_Entrevista(
    p_data IN entrevista.data%TYPE,
    p_valoracio IN entrevista.valoracio%TYPE,
    p_experiencia IN entrevista.experiencia%TYPE,
    p_data_acceptacio IN entrevista.data_acceptacio%TYPE,
    p_id_persona IN Entrevista.id_persona%TYPE,
    p_id_oferta IN entrevista.id_oferta%TYPE)
IS
    hora_inici logbd.hora_inici%TYPE;
    v_id_entrevista entrevista.id_entrevista%TYPE;
    parametres logbd.param_procediment%TYPE;

BEGIN

  SELECT SYSDATE INTO hora_inici FROM DUAL;
  
  v_id_entrevista:=s_entrevista.nextval;
    
  parametres:= v_id_entrevista || ';' || p_data || ';' || p_valoracio || ';' || p_experiencia || ';' || p_data_acceptacio || ';' || p_id_persona || ';' || p_id_oferta;
  INSERT INTO Entrevista ("ID_ENTREVISTA","DATA","VALORACIO","EXPERIENCIA","DATA_ACCEPTACIO","ID_PERSONA","ID_OFERTA")
	VALUES (v_id_entrevista,p_data,p_valoracio,p_experiencia,p_data_acceptacio,p_id_persona,p_id_oferta);

  dbms_output.put_line('1 Entrevista Creada');
	sp_i_logbd('sp_i_Entrevista',parametres,hora_inici,sysdate,sqlerrm);

  COMMIT;
  EXCEPTION
   WHEN OTHERS THEN 
      ROLLBACK;
      DBMS_OUTPUT.PUT_LINE(sqlerrm);
      sp_i_logbd('sp_i_Entrevista',parametres,hora_inici,sysdate,sqlerrm);
END;
/

--
-- Definition for procedure SP_S_ENTREVISTA
--
CREATE OR REPLACE PROCEDURE sp_s_Entrevista(
    p_id_Entrevista IN Entrevista.id_Entrevista%TYPE)
IS
  hora_inici logbd.hora_inici%TYPE;
  rec_Entrevista Entrevista%ROWTYPE;
  
  parametres logbd.param_procediment%TYPE;
	 
BEGIN
 
  SELECT SYSDATE INTO hora_inici FROM DUAL;

  SELECT * INTO rec_Entrevista FROM Entrevista
  WHERE id_Entrevista = p_id_Entrevista;

  DBMS_OUTPUT.PUT_LINE('ID Entrevista:' || rec_Entrevista.id_Entrevista || ' ' || 'DATA:' || rec_entrevista.data || ' ' || 'VALORACIO:' || rec_Entrevista.valoracio || ' ' || 'EXPERIENCIA:' ||
                        rec_Entrevista.experiencia || ' ' || 'DATA ACCEPTACI:' || rec_Entrevista.data_acceptacio || ' ' || 'ID PERSONA:' || rec_entrevista.id_persona || ' ' || 'ID.OFERTA:' || rec_Entrevista.id_oferta);

  sp_i_logbd('sp_s_Entrevista',p_id_Entrevista,hora_inici,sysdate,sqlerrm);
  COMMIT;

  EXCEPTION
    WHEN NO_DATA_FOUND THEN
    DBMS_OUTPUT.PUT_LINE('Registre no trobat');
    sp_i_logbd('sp_s_Entrevista',p_id_Entrevista,hora_inici,sysdate,sqlerrm);
END;
/

--
-- Definition for procedure SP_D_ENTREVISTA
--
CREATE OR REPLACE PROCEDURE sp_d_Entrevista(
		p_id_Entrevista IN Entrevista.id_Entrevista%TYPE)
IS
    hora_inici logbd.hora_inici%TYPE;
    id_Entrevista Entrevista.id_Entrevista%TYPE;
     
BEGIN
  SELECT SYSDATE INTO hora_inici FROM DUAL;
  
  SELECT id_Entrevista INTO id_Entrevista FROM Entrevista 
  WHERE id_Entrevista = p_id_Entrevista;

  DELETE Entrevista WHERE id_Entrevista = p_id_Entrevista;
  DBMS_OUTPUT.PUT_LINE('Registre Entrevista esborrat');
  sp_i_logbd('sp_d_Entrevista',p_id_Entrevista,hora_inici,sysdate,sqlerrm);
  COMMIT;
 
  EXCEPTION
     WHEN NO_DATA_FOUND THEN
       DBMS_OUTPUT.PUT_LINE('Registre no trobat');
       sp_i_logbd('sp_d_Entrevista',p_id_Entrevista,hora_inici,sysdate,sqlerrm);
     WHEN OTHERS THEN 
       ROLLBACK;
       DBMS_OUTPUT.PUT_LINE(sqlerrm);
       sp_i_logbd('sp_d_Entrevista',p_id_Entrevista,hora_inici,sysdate,sqlerrm);
END;
/

--
-- Definition for procedure SP_U_ENTREVISTA
--
CREATE OR REPLACE PROCEDURE sp_u_Entrevista(
    p_id_Entrevista IN Entrevista.id_Entrevista%TYPE,
    p_data IN entrevista.data%TYPE,
    p_valoracio IN entrevista.valoracio%TYPE,
    p_experiencia IN entrevista.experiencia%TYPE,
    p_data_acceptacio IN entrevista.data_acceptacio%TYPE,
    p_id_persona IN Entrevista.id_persona%TYPE,
    p_id_oferta IN entrevista.id_oferta%TYPE)
    
IS
  hora_inici logbd.hora_inici%TYPE;
	rec_Entrevista Entrevista%ROWTYPE;
  parametres logbd.param_procediment%TYPE;
  
BEGIN

   SELECT SYSDATE INTO hora_inici FROM DUAL;

   parametres:= p_id_entrevista || ';' || p_data || ';' || p_valoracio || ';' || p_experiencia || ';' || p_data_acceptacio || ';' || p_id_persona || ';' || p_id_oferta;

   SELECT * INTO rec_Entrevista FROM Entrevista 
   WHERE id_Entrevista = p_id_Entrevista;
      
   IF p_data IS NOT NULL THEN rec_Entrevista.data:= p_data;
   END IF;
   IF p_valoracio IS NOT NULL THEN rec_Entrevista.valoracio:= p_valoracio;
   END IF;
   IF p_experiencia IS NOT NULL THEN rec_Entrevista.experiencia:= p_experiencia;
   END IF;
   IF p_data_acceptacio IS NOT NULL THEN rec_Entrevista.data_acceptacio:= p_data_acceptacio;
   END IF;
   IF p_id_persona IS NOT NULL THEN rec_Entrevista.id_persona:= p_id_persona;
   END IF;
   IF p_id_oferta IS NOT NULL THEN rec_Entrevista.id_oferta:= p_id_oferta;
   END IF;
   
   UPDATE Entrevista SET ROW = rec_Entrevista
   WHERE id_Entrevista = p_id_Entrevista;
  
   dbms_output.put_line('Entrevista actualitzada');
   sp_i_logbd('sp_u_Entrevista',parametres,hora_inici,sysdate,sqlerrm);
   COMMIT;
  
   EXCEPTION
      WHEN NO_DATA_FOUND THEN
         DBMS_OUTPUT.PUT_LINE('Registre no trobat');
         sp_i_logbd('sp_u_Entrevista',parametres,hora_inici,sysdate,sqlerrm);
      WHEN OTHERS THEN 
         ROLLBACK;
         DBMS_OUTPUT.PUT_LINE(sqlerrm);
         sp_i_logbd('sp_u_Entrevista',parametres,hora_inici,sysdate,sqlerrm);
END;
/

--
-- Definition for procedure SP_I_CURRICULUM
--
CREATE OR REPLACE PROCEDURE sp_i_Curriculum(
		p_data IN Curriculum.data%TYPE,
    p_id_persona IN curriculum.id_persona%TYPE)
IS
    v_id_curriculum curriculum.id_curriculum%TYPE;
    hora_inici logbd.hora_inici%TYPE;
    parametres logbd.param_procediment%TYPE;

BEGIN

  SELECT SYSDATE INTO hora_inici FROM DUAL;
  
  v_id_curriculum:=s_Curriculum.nextval;
  parametres:= v_id_curriculum  || ';' || p_data  || ';' || p_id_persona;
  INSERT INTO Curriculum ("ID_CURRICULUM","DATA","ID_PERSONA")
	VALUES (v_id_curriculum,p_data,p_id_persona);

  dbms_output.put_line('1 Curriculum Creat');
	
  sp_i_logbd('sp_i_Curriculum',parametres,hora_inici,sysdate,sqlerrm);
	COMMIT;

  EXCEPTION
   WHEN OTHERS THEN 
      ROLLBACK;
      DBMS_OUTPUT.PUT_LINE(sqlerrm);
      sp_i_logbd('sp_i_Curriculum',parametres,hora_inici,sysdate,sqlerrm);
END;
/

--
-- Definition for procedure SP_S_CURRICULUM
--
CREATE OR REPLACE PROCEDURE sp_s_Curriculum(
    p_id_Curriculum IN Curriculum.id_curriculum%TYPE)
IS
  hora_inici logbd.hora_inici%TYPE;
  rec_curriculum curriculum%ROWTYPE;
  
BEGIN

  SELECT SYSDATE INTO hora_inici FROM DUAL;
  
  SELECT * INTO rec_curriculum FROM Curriculum 
  WHERE id_Curriculum = p_id_Curriculum;
  
  DBMS_OUTPUT.PUT_LINE('ID.CURRICULUM: ' || p_id_curriculum || ' DATA: ' || rec_curriculum.data || ' ID PERSONA: ' || rec_curriculum.id_persona);
  
  sp_i_logbd('sp_s_Curriculum',p_id_Curriculum,hora_inici,sysdate,sqlerrm);
  COMMIT;

  EXCEPTION
    WHEN NO_DATA_FOUND THEN
    DBMS_OUTPUT.PUT_LINE('Registre no trobat');
    sp_i_logbd('sp_s_Curriculum',p_id_Curriculum,hora_inici,sysdate,sqlerrm);
END;
/

--
-- Definition for procedure SP_D_CURRICULUM
--
CREATE OR REPLACE PROCEDURE sp_d_Curriculum(
		p_id_Curriculum IN Curriculum.ID_Curriculum%TYPE)
IS
    hora_inici logbd.hora_inici%TYPE;
    codi_Curriculum Curriculum.id_Curriculum%TYPE;
     
BEGIN
  SELECT SYSDATE INTO hora_inici FROM DUAL;
  

  SELECT id_Curriculum INTO codi_Curriculum FROM Curriculum 
  WHERE id_Curriculum = p_id_Curriculum;

  DELETE Curriculum WHERE ID_Curriculum = p_id_Curriculum;
  DBMS_OUTPUT.PUT_LINE('Registre Curriculum esborrat');
  sp_i_logbd('sp_d_Curriculum',p_id_Curriculum,hora_inici,sysdate,sqlerrm);
  COMMIT;
 
  EXCEPTION
     WHEN NO_DATA_FOUND THEN
       DBMS_OUTPUT.PUT_LINE('Registre no trobat');
       sp_i_logbd('sp_d_Curriculum',p_id_Curriculum,hora_inici,sysdate,sqlerrm);
     WHEN OTHERS THEN 
       ROLLBACK;
       DBMS_OUTPUT.PUT_LINE(sqlerrm);
       sp_i_logbd('sp_d_Curriculum',p_id_Curriculum,hora_inici,sysdate,sqlerrm);
END;
/

--
-- Definition for procedure SP_U_CURRICULUM
--
CREATE OR REPLACE PROCEDURE sp_u_Curriculum(
    p_id_Curriculum IN Curriculum.id_curriculum%TYPE,
		p_data IN Curriculum.data%TYPE,
    p_id_persona IN curriculum.id_persona%TYPE)
IS
  hora_inici logbd.hora_inici%TYPE;
	rec_Curriculum Curriculum%ROWTYPE;
  parametres logbd.param_procediment%TYPE;
  
BEGIN

   SELECT SYSDATE INTO hora_inici FROM DUAL;

   parametres:= p_id_Curriculum || ';' || p_data || ';' || p_id_persona;

   SELECT * INTO rec_Curriculum FROM Curriculum 
   WHERE id_Curriculum = p_id_Curriculum;
      
   IF p_data IS NOT NULL THEN rec_Curriculum.data:= p_data;
   END IF;
   IF p_id_persona IS NOT NULL THEN rec_Curriculum.id_persona:= p_id_persona;
   END IF;
      
   UPDATE Curriculum SET ROW = rec_Curriculum
   WHERE id_Curriculum = p_id_Curriculum;
  
   dbms_output.put_line('Curriculum actualitzat');
   sp_i_logbd('sp_u_Curriculum',parametres,hora_inici,sysdate,sqlerrm);
   COMMIT;
  
   EXCEPTION
      WHEN NO_DATA_FOUND THEN
         DBMS_OUTPUT.PUT_LINE('Registre no trobat');
         sp_i_logbd('sp_u_Curriculum',parametres,hora_inici,sysdate,sqlerrm);
      WHEN OTHERS THEN 
         ROLLBACK;
         DBMS_OUTPUT.PUT_LINE(sqlerrm);
         sp_i_logbd('sp_u_Curriculum',parametres,hora_inici,sysdate,sqlerrm);
END;
/

--
-- Definition for procedure SP_I_FORMACIO
--
CREATE OR REPLACE PROCEDURE sp_i_Formacio(
   p_data_inici IN Formacio.data_inici%TYPE,
   p_data_fi IN Formacio.data_fi%TYPE,
   p_id_curriculum IN Formacio.id_curriculum%TYPE,
   p_id_titulacio IN Formacio.id_titulacio%TYPE,
   p_id_persona IN Formacio.id_persona%TYPE)
IS
    id_Formacio_nextval Formacio.id_Formacio%TYPE;
    hora_inici logbd.hora_inici%TYPE;
    parametres logbd.param_procediment%TYPE;

BEGIN

  SELECT SYSDATE INTO hora_inici FROM DUAL;
  
  id_Formacio_nextval:= s_Formacio.nextval;
  parametres:= id_Formacio_nextval || ';' || p_data_inici || ';' || p_data_fi || ';' || p_id_curriculum || ';' || p_id_titulacio || ';' || p_id_persona;

  INSERT INTO Formacio ("ID_FORMACIO","DATA_INICI","DATA_FI","ID_CURRICULUM","ID_TITULACIO","ID_PERSONA")
	VALUES (id_Formacio_nextval,p_data_inici,p_data_fi,p_id_curriculum,p_id_titulacio,p_id_persona);

  dbms_output.put_line('1 Formaci Creada');
	sp_i_logbd('sp_i_Formacio',parametres,hora_inici,sysdate,sqlerrm);

  COMMIT;
  EXCEPTION
   WHEN OTHERS THEN 
      ROLLBACK;
      DBMS_OUTPUT.PUT_LINE(sqlerrm);
      sp_i_logbd('sp_i_Formacio',parametres,hora_inici,sysdate,sqlerrm);
END;
/

--
-- Definition for procedure SP_S_FORMACIO
--
CREATE OR REPLACE PROCEDURE sp_s_Formacio(
  p_id_Formacio IN Formacio.id_Formacio%TYPE)
  
IS
  hora_inici logbd.hora_inici%TYPE;
  rec_Formacio Formacio%ROWTYPE;
  parametres logbd.param_procediment%TYPE;
	 
BEGIN
 
  SELECT SYSDATE INTO hora_inici FROM DUAL;

  SELECT * INTO rec_Formacio FROM Formacio
  WHERE id_Formacio = p_id_Formacio;

  DBMS_OUTPUT.PUT_LINE('ID Formacio:' || rec_Formacio.id_Formacio || ' ' || 'DATA INICI:' || rec_Formacio.data_inici || ' ' || 'DATA FI:' || rec_Formacio.data_fi || ' ' || 'ID.CURRICULUM:' ||
                        rec_Formacio.id_curriculum || ' ' || 'ID.TITULACI:' || rec_Formacio.id_titulacio || ' ' || 'EMPRESA:' || rec_Formacio.id_persona);
  sp_i_logbd('sp_s_Formacio',p_id_Formacio,hora_inici,sysdate,sqlerrm);
  COMMIT;

  EXCEPTION
    WHEN NO_DATA_FOUND THEN
    DBMS_OUTPUT.PUT_LINE('Registre no trobat');
    sp_i_logbd('sp_s_Formacio',p_id_Formacio,hora_inici,sysdate,sqlerrm);
END;
/

--
-- Definition for procedure SP_D_FORMACIO
--
CREATE OR REPLACE PROCEDURE sp_d_Formacio(
		p_id_Formacio IN Formacio.id_Formacio%TYPE)
IS
    hora_inici logbd.hora_inici%TYPE;
    id_Formacio Formacio.id_Formacio%TYPE;
     
BEGIN
  SELECT SYSDATE INTO hora_inici FROM DUAL;
  
  SELECT id_Formacio INTO id_Formacio FROM Formacio 
  WHERE id_Formacio = p_id_Formacio;

  DELETE Formacio WHERE id_Formacio = p_id_Formacio;
  DBMS_OUTPUT.PUT_LINE('Registre Formacio esborrat');
  sp_i_logbd('sp_d_Formacio',p_id_Formacio,hora_inici,sysdate,sqlerrm);
  COMMIT;
 
  EXCEPTION
     WHEN NO_DATA_FOUND THEN
       DBMS_OUTPUT.PUT_LINE('Registre no trobat');
       sp_i_logbd('sp_d_Formacio',p_id_Formacio,hora_inici,sysdate,sqlerrm);
     WHEN OTHERS THEN 
       ROLLBACK;
       DBMS_OUTPUT.PUT_LINE(sqlerrm);
       sp_i_logbd('sp_d_Formacio',p_id_Formacio,hora_inici,sysdate,sqlerrm);
END;
/

--
-- Definition for procedure SP_U_FORMACIO
--
CREATE OR REPLACE PROCEDURE sp_u_Formacio(
   p_id_formacio IN formacio.id_formacio%TYPE,
   p_data_inici IN Formacio.data_inici%TYPE,
   p_data_fi IN Formacio.data_fi%TYPE,
   p_id_curriculum IN Formacio.id_curriculum%TYPE,
   p_id_titulacio IN Formacio.id_titulacio%TYPE,
   p_id_persona IN Formacio.id_persona%TYPE)
IS
  hora_inici logbd.hora_inici%TYPE;
	rec_Formacio Formacio%ROWTYPE;
  parametres logbd.param_procediment%TYPE;
  
BEGIN

   SELECT SYSDATE INTO hora_inici FROM DUAL;

   parametres:= p_id_Formacio || ';' || p_data_inici || ';' || p_data_fi || ';' || p_id_curriculum || ';' || p_id_titulacio || ';' || p_id_persona ;

   SELECT * INTO rec_Formacio FROM Formacio 
   WHERE id_Formacio = p_id_Formacio;
      
   IF p_data_inici IS NOT NULL THEN rec_Formacio.data_inici:= p_data_inici;
   END IF;
   IF p_data_fi IS NOT NULL THEN rec_Formacio.data_fi:= p_data_fi;
   END IF;
   IF p_id_curriculum IS NOT NULL THEN rec_Formacio.id_curriculum:= p_id_curriculum;
   END IF;
   IF p_id_titulacio IS NOT NULL THEN rec_Formacio.id_titulacio:= p_id_titulacio;
   END IF;
   IF p_id_persona IS NULL THEN rec_Formacio.id_persona:= p_id_persona;
   END IF;
   
   
   UPDATE Formacio SET ROW = rec_Formacio
   WHERE id_Formacio = p_id_Formacio;
  
   dbms_output.put_line('Formacio actualitzada');
   sp_i_logbd('sp_u_Formacio',parametres,hora_inici,sysdate,sqlerrm);
   COMMIT;
  
   EXCEPTION
      WHEN NO_DATA_FOUND THEN
         DBMS_OUTPUT.PUT_LINE('Registre no trobat');
         sp_i_logbd('sp_u_Formacio',parametres,hora_inici,sysdate,sqlerrm);
      WHEN OTHERS THEN 
         ROLLBACK;
         DBMS_OUTPUT.PUT_LINE(sqlerrm);
         sp_i_logbd('sp_u_Formacio',parametres,hora_inici,sysdate,sqlerrm);
END;
/

--
-- Definition for procedure SP_I_EXP_LABORAL
--
CREATE OR REPLACE PROCEDURE sp_i_Exp_Laboral(
    p_data_inici IN exp_laboral.data_inici%TYPE,
    p_data_fi IN exp_laboral.data_fi%TYPE,
    p_id_perfil IN exp_laboral.id_perfil%TYPE,
    p_id_curriculum IN exp_laboral.id_curriculum%TYPE,
    p_id_persona IN exp_laboral.id_persona%TYPE)
IS
    hora_inici logbd.hora_inici%TYPE;
    parametres logbd.param_procediment%TYPE;
    s_id_Exp_Laboral Exp_Laboral.id_Exp_Laboral%TYPE;
    
BEGIN

  SELECT SYSDATE INTO hora_inici FROM DUAL;
  
  s_id_Exp_Laboral:= s_Exp_Laboral.nextval;
  parametres:=s_id_Exp_Laboral || ';' || p_data_inici || ';' || p_data_fi || ';' || p_id_perfil || ';' || p_id_curriculum || ';' || p_id_persona;
  
  INSERT INTO Exp_Laboral ("ID_EXP_LABORAL","DATA_INICI","DATA_FI","ID_PERFIL","ID_CURRICULUM","ID_PERSONA")
	VALUES (s_id_Exp_Laboral,p_data_inici,p_data_fi,p_id_perfil,p_id_curriculum,p_id_persona);

  dbms_output.put_line('1 Exp_Laboral creada');
  sp_i_logbd('sp_i_Exp_Laboral',parametres,hora_inici,sysdate,sqlerrm);
   
	COMMIT;

  EXCEPTION
  WHEN OTHERS THEN 
      ROLLBACK;
      DBMS_OUTPUT.PUT_LINE(sqlerrm);
      sp_i_logbd('sp_i_Exp_Laboral',parametres,hora_inici,sysdate,sqlerrm);
END;
/

--
-- Definition for procedure SP_S_EXP_LABORAL
--
CREATE OR REPLACE PROCEDURE sp_s_Exp_Laboral(
    p_id_Exp_Laboral IN Exp_Laboral.id_Exp_Laboral%TYPE)
IS
  hora_inici logbd.hora_inici%TYPE;
  rec_Exp_Laboral Exp_Laboral%ROWTYPE;
  parametres logbd.param_procediment%TYPE;
	 
BEGIN
 
  SELECT SYSDATE INTO hora_inici FROM DUAL;

  SELECT * INTO rec_Exp_Laboral FROM Exp_Laboral
  WHERE id_Exp_Laboral = p_id_Exp_Laboral;

  DBMS_OUTPUT.PUT_LINE('ID Exp_Laboral:' || rec_Exp_Laboral.id_Exp_Laboral || ' ' || 'DATA INICI:' || rec_Exp_Laboral.data_inici || ' ' || 'DATA FI:' || rec_Exp_Laboral.data_fi || ' ' || 'PERFIL:' ||
                        rec_Exp_Laboral.id_perfil || ' ' || 'ID.CURRICULUM:' || rec_Exp_Laboral.id_curriculum || ' ' || 'EMPRESA:' || rec_Exp_Laboral.id_persona);
  sp_i_logbd('sp_s_Exp_Laboral',p_id_Exp_Laboral,hora_inici,sysdate,sqlerrm);
  COMMIT;

  EXCEPTION
    WHEN NO_DATA_FOUND THEN
    DBMS_OUTPUT.PUT_LINE('Registre no trobat');
    sp_i_logbd('sp_s_Exp_Laboral',p_id_Exp_Laboral,hora_inici,sysdate,sqlerrm);
END;
/

--
-- Definition for procedure SP_D_EXP_LABORAL
--
CREATE OR REPLACE PROCEDURE sp_d_Exp_Laboral(
		p_id_Exp_Laboral IN Exp_Laboral.id_Exp_Laboral%TYPE)
IS
    hora_inici logbd.hora_inici%TYPE;
    id_Exp_Laboral Exp_Laboral.id_Exp_Laboral%TYPE;
      
BEGIN
  SELECT SYSDATE INTO hora_inici FROM DUAL;
  
  SELECT id_Exp_Laboral INTO id_Exp_Laboral FROM Exp_Laboral 
  WHERE id_Exp_Laboral = p_id_Exp_Laboral;

  DELETE Exp_Laboral WHERE id_Exp_Laboral = p_id_Exp_Laboral;
  DBMS_OUTPUT.PUT_LINE('Registre Exp_Laboral esborrat');
  sp_i_logbd('sp_d_Exp_Laboral',p_id_Exp_Laboral,hora_inici,sysdate,sqlerrm);
  COMMIT;

  EXCEPTION
     WHEN NO_DATA_FOUND THEN
       DBMS_OUTPUT.PUT_LINE('Registre no trobat');
       sp_i_logbd('sp_d_Exp_Laboral',p_id_Exp_Laboral,hora_inici,sysdate,sqlerrm);
     WHEN OTHERS THEN 
       ROLLBACK;
       DBMS_OUTPUT.PUT_LINE(sqlerrm);
       sp_i_logbd('sp_d_Exp_Laboral',p_id_Exp_Laboral,hora_inici,sysdate,sqlerrm);
END;
/

--
-- Definition for procedure SP_U_EXP_LABORAL
--
CREATE OR REPLACE PROCEDURE sp_u_Exp_Laboral(
    p_id_Exp_Laboral IN Exp_Laboral.id_Exp_Laboral%TYPE,
    p_data_inici IN exp_laboral.data_inici%TYPE,
    p_data_fi IN exp_laboral.data_fi%TYPE,
    p_id_perfil IN exp_laboral.id_perfil%TYPE,
    p_id_curriculum IN exp_laboral.id_curriculum%TYPE,
    p_id_persona IN exp_laboral.id_persona%TYPE)
    
IS
  hora_inici logbd.hora_inici%TYPE;
	rec_Exp_Laboral Exp_Laboral%ROWTYPE;
  parametres logbd.param_procediment%TYPE;
  
BEGIN

   SELECT SYSDATE INTO hora_inici FROM DUAL;

   parametres:= p_id_Exp_Laboral || ';' || p_data_inici || ';' || p_data_fi || ';' ||
                p_id_perfil || ';' || p_id_curriculum || ';' || p_id_persona;

   SELECT * INTO rec_Exp_Laboral FROM Exp_Laboral 
   WHERE id_Exp_Laboral = p_id_Exp_Laboral;
      
   IF p_data_inici IS NOT NULL THEN rec_Exp_Laboral.data_inici:= p_data_inici;
   END IF;
   IF p_data_fi IS NOT NULL THEN rec_Exp_Laboral.data_fi:= p_data_fi;
   END IF;
   IF p_id_perfil IS NOT NULL THEN rec_Exp_Laboral.id_perfil:= p_id_perfil;
   END IF;
   IF p_id_curriculum IS NOT NULL THEN rec_Exp_Laboral.id_curriculum:= p_id_curriculum;
   END IF;
   IF p_id_persona IS NOT NULL THEN rec_Exp_Laboral.id_persona:= p_id_persona;
   END IF;
   
   UPDATE Exp_Laboral SET ROW = rec_Exp_Laboral
   WHERE id_Exp_Laboral = p_id_Exp_Laboral;
  
   dbms_output.put_line('Exp_Laboral actualitzada');
   sp_i_logbd('sp_u_Exp_Laboral',parametres,hora_inici,sysdate,sqlerrm);
   COMMIT;
  
   EXCEPTION
      WHEN NO_DATA_FOUND THEN
         DBMS_OUTPUT.PUT_LINE('Registre no trobat');
         sp_i_logbd('sp_u_Exp_Laboral',parametres,hora_inici,sysdate,sqlerrm);
      WHEN OTHERS THEN 
         ROLLBACK;
         DBMS_OUTPUT.PUT_LINE(sqlerrm);
         sp_i_logbd('sp_u_Exp_Laboral',parametres,hora_inici,sysdate,sqlerrm);
END;
/

--
-- Definition for procedure SP_Q_OFERTA_EMPRESA
--
CREATE OR REPLACE PROCEDURE sp_q_Oferta_Empresa(
    p_id_persona IN Persona.id_persona%TYPE)
 
IS
  hora_inici logbd.hora_inici%TYPE;
  empresa_nom persona.nom_complet%TYPE;

  CURSOR r_cursor IS
      SELECT * FROM v_ofertes
		  WHERE id_persona = p_id_persona and data_oferta_coberta is null;
   
BEGIN

  SELECT SYSDATE INTO hora_inici FROM DUAL;

  SELECT nom_complet INTO empresa_nom FROM persona
  WHERE id_persona = p_id_persona;

  dbms_output.put_line('EMPRESA: ' || p_id_persona || ' ' || empresa_nom);
  dbms_output.put_line('-------------------------------------------------------------------------------------------------------------');
  
  FOR r_oferta_empresa IN r_cursor LOOP
      dbms_output.put_line('DATA:' || r_oferta_empresa.data || ' ' || 'HORES:' || r_oferta_empresa.hores || ' ' || 'PERIODICITAT:' || 
                            r_oferta_empresa.periodicitat || ' ' || 'TIPUS JORNADA:' || r_oferta_empresa.tipus_jornada || ' ' || 
                            'PERFIL:' || r_oferta_empresa.descripcio || ' ' || 'PLACES:' || r_oferta_empresa.num_places || ' ' ||
                            'PRIORITAT:' || r_oferta_empresa.prioritat);
  END LOOP;
  sp_i_logbd('sp_q_oferta_empresa',p_id_persona,hora_inici,sysdate,sqlerrm);

  EXCEPTION
     WHEN NO_DATA_FOUND THEN
       DBMS_OUTPUT.PUT_LINE('Empresa inexistent');
       sp_i_logbd('sp_q_oferta_empresa',p_id_persona,hora_inici,sysdate,sqlerrm);
     WHEN OTHERS THEN 
       DBMS_OUTPUT.PUT_LINE(sqlerrm);
       sp_i_logbd('sp_q_oferta_empresa',p_id_persona,hora_inici,sysdate,sqlerrm);
END;
/

--
-- Definition for procedure SP_Q_OFERTA_PERFIL
--
CREATE OR REPLACE PROCEDURE sp_q_Oferta_Perfil(
    p_id_perfil IN perfil.id_perfil%TYPE)
 
IS
  hora_inici logbd.hora_inici%TYPE;
  desc_perfil perfil.descripcio%TYPE;
 
  CURSOR r_cursor IS
      SELECT * FROM v_ofertes
		  WHERE id_perfil = p_id_perfil AND data_oferta_coberta is null;
BEGIN

  SELECT SYSDATE INTO hora_inici FROM DUAL;

  SELECT descripcio INTO desc_perfil FROM perfil
  WHERE id_perfil = p_id_perfil;

  dbms_output.put_line('PERFIL: ' || p_id_perfil || ' ' || desc_perfil);
  dbms_output.put_line('---------------------------------------------------------------------------------------------------------------------');
   
  FOR r_oferta_perfil IN r_cursor LOOP
      dbms_output.put_line('NIF:' || r_oferta_perfil.dni || ' ' || 'EMPRESA:' || r_oferta_perfil.nom_complet || ' ' || 'DATA:' || 
                            r_oferta_perfil.data || ' ' || 'HORES:' || r_oferta_perfil.hores || ' ' || 'PERIODICITAT:' || 
                            r_oferta_perfil.periodicitat || ' ' || 'TIPUS JORNADA:' || r_oferta_perfil.tipus_jornada || ' ' || 
                            'PLACES:' || r_oferta_perfil.num_places || ' ' ||
                            'PRIORITAT:' || r_oferta_perfil.prioritat);
  END LOOP;
  sp_i_logbd('sp_q_oferta_perfil',p_id_perfil,hora_inici,sysdate,sqlerrm);

  EXCEPTION
     WHEN NO_DATA_FOUND THEN
       DBMS_OUTPUT.PUT_LINE('Perfil inexistent');
       sp_i_logbd('sp_q_oferta_perfil',p_id_perfil,hora_inici,sysdate,sqlerrm);
     WHEN OTHERS THEN 
       DBMS_OUTPUT.PUT_LINE(sqlerrm);
       sp_i_logbd('sp_q_oferta_perfil',p_id_perfil,hora_inici,sysdate,sqlerrm);
END;
/

--
-- Definition for procedure SP_Q_OFERTA_SALARI
--
CREATE OR REPLACE PROCEDURE sp_q_Oferta_Salari(
    p_salari IN solicitud.salari%TYPE)
     
IS
  hora_inici logbd.hora_inici%TYPE;
 
  CURSOR r_cursor IS
     SELECT * FROM v_ofertes
		  WHERE salari >= p_salari and data_oferta_coberta is null;
BEGIN

  SELECT SYSDATE INTO hora_inici FROM DUAL;

  dbms_output.put_line('SALARI: ' || p_salari);
  dbms_output.put_line('--------------------------------------------------------------------------------------------------------------------');

  FOR r_oferta_empresa IN r_cursor LOOP        
        dbms_output.put_line('DATA:' || r_oferta_empresa.data || ' ' || 'HORES:' || r_oferta_empresa.hores || ' ' || 'PERIODICITAT:' || 
                            r_oferta_empresa.periodicitat || ' ' || 'TIPUS JORNADA:' || r_oferta_empresa.tipus_jornada || ' ' || 
                            'SALARI:' || r_oferta_empresa.salari || ' ' || 'PERFIL:' || r_oferta_empresa.descripcio || ' ' ||
                            'PLACES:' || r_oferta_empresa.num_places || ' ' || 'PRIORITAT:' || r_oferta_empresa.prioritat);
  END LOOP;

  sp_i_logbd('sp_q_oferta_salari',p_salari,hora_inici,sysdate,sqlerrm);

  EXCEPTION
     WHEN OTHERS THEN 
       DBMS_OUTPUT.PUT_LINE(sqlerrm);
       sp_i_logbd('sp_q_oferta_salari',p_salari,hora_inici,sysdate,sqlerrm);
END;
/

--
-- Definition for procedure SP_I_IDIOMA
--
CREATE OR REPLACE PROCEDURE sp_i_Idioma(
		p_descripcio IN idioma.descripcio%TYPE)
IS
    hora_inici logbd.hora_inici%TYPE;

BEGIN

  SELECT SYSDATE INTO hora_inici FROM DUAL;
  
  INSERT INTO idioma ("ID_IDIOMA","DESCRIPCIO")
	VALUES (s_Idioma.NEXTVAL,p_descripcio);

  dbms_output.put_line('1 Idioma creat');
	
  sp_i_logbd('sp_i_Idioma',p_descripcio,hora_inici,sysdate,sqlerrm);
   
	COMMIT;
  EXCEPTION
  WHEN OTHERS THEN 
      ROLLBACK;
      DBMS_OUTPUT.PUT_LINE(sqlerrm);
      sp_i_logbd('sp_i_Idioma',p_descripcio,hora_inici,sysdate,sqlerrm);
END;
/

--
-- Definition for procedure SP_D_IDIOMA
--
CREATE OR REPLACE PROCEDURE sp_d_Idioma(
		p_id_Idioma IN Idioma.ID_Idioma%TYPE)
IS
    hora_inici logbd.hora_inici%TYPE;
    codi_Idioma Idioma.id_Idioma%TYPE;
      
BEGIN
  SELECT SYSDATE INTO hora_inici FROM DUAL;
  
  SELECT id_Idioma INTO codi_Idioma FROM Idioma 
  WHERE id_Idioma = p_id_Idioma;

  DELETE Idioma WHERE ID_Idioma = p_id_Idioma;
  DBMS_OUTPUT.PUT_LINE('Registre Idioma esborrat');
  sp_i_logbd('sp_d_Idioma',p_id_Idioma,hora_inici,sysdate,sqlerrm);
  COMMIT;

  EXCEPTION
     WHEN NO_DATA_FOUND THEN
       DBMS_OUTPUT.PUT_LINE('Registre no trobat');
       sp_i_logbd('sp_d_Idioma',p_id_Idioma,hora_inici,sysdate,sqlerrm);
     WHEN OTHERS THEN 
       ROLLBACK;
       DBMS_OUTPUT.PUT_LINE(sqlerrm);
       sp_i_logbd('sp_d_Idioma',p_id_Idioma,hora_inici,sysdate,sqlerrm);
END;
/

--
-- Definition for procedure SP_S_IDIOMA
--
CREATE OR REPLACE PROCEDURE sp_s_Idioma(
    p_id_Idioma IN Idioma.id_idioma%TYPE)
IS
  hora_inici logbd.hora_inici%TYPE;
	codi_idioma Idioma.id_Idioma%TYPE;
  desc_idioma Idioma.descripcio%TYPE;
  
BEGIN
 
  SELECT SYSDATE INTO hora_inici FROM DUAL;
  
  SELECT id_Idioma,descripcio INTO codi_idioma,desc_idioma FROM Idioma 
  WHERE id_Idioma = p_id_Idioma;
  
  DBMS_OUTPUT.PUT_LINE(to_char(p_id_Idioma) || ' '  || ' ' || desc_idioma);
  
  sp_i_logbd('sp_s_Idioma',p_id_Idioma,hora_inici,sysdate,sqlerrm);
  COMMIT;

  EXCEPTION
    WHEN NO_DATA_FOUND THEN
    DBMS_OUTPUT.PUT_LINE('Registre no trobat');
    sp_i_logbd('sp_s_Idioma',p_id_Idioma,hora_inici,sysdate,sqlerrm);
END;
/

--
-- Definition for procedure SP_U_IDIOMA
--
CREATE OR REPLACE PROCEDURE sp_u_Idioma(
    p_id_Idioma IN Idioma.id_idioma%TYPE,
		p_descripcio IN Idioma.descripcio%TYPE)
IS
  hora_inici logbd.hora_inici%TYPE;
	codi_Idioma Idioma.id_Idioma%TYPE;
  parametres logbd.param_procediment%TYPE;
   
BEGIN

  SELECT SYSDATE INTO hora_inici FROM DUAL;
  parametres:= p_descripcio || ';' || p_id_Idioma;

  SELECT id_Idioma INTO codi_idioma FROM Idioma 
  WHERE id_Idioma = p_id_Idioma;
      
  UPDATE Idioma SET descripcio = p_descripcio 
  WHERE id_Idioma = p_id_Idioma;

  dbms_output.put_line('Idioma actualitzat');
	sp_i_logbd('sp_u_Idioma',parametres,hora_inici,sysdate,sqlerrm);
  COMMIT;

  EXCEPTION
    WHEN NO_DATA_FOUND THEN
    DBMS_OUTPUT.PUT_LINE('Registre no trobat');
    sp_i_logbd('sp_u_Idioma',parametres,hora_inici,sysdate,sqlerrm);
END;
/

--
-- Definition for procedure SP_I_IDIOMA_CV
--
CREATE OR REPLACE PROCEDURE sp_i_Idioma_CV(
   p_nivell_escrit IN idioma_cv.nivell_escrit%TYPE,
   p_nivell_parlat IN idioma_cv.nivell_parlat%TYPE,
   p_id_curriculum IN idioma_cv.id_curriculum%TYPE,
   p_id_idioma IN idioma_cv.id_idioma%TYPE)

IS
    id_idioma_cv_nextval idioma_cv.id_idioma_cv%TYPE;
    hora_inici logbd.hora_inici%TYPE;
    parametres logbd.param_procediment%TYPE;
 
BEGIN

  SELECT SYSDATE INTO hora_inici FROM DUAL;
  
  id_idioma_cv_nextval:= s_idioma_cv.nextval;
  parametres:= id_idioma_cv_nextval || ';' || p_nivell_escrit || ';' || p_nivell_parlat || ';' || p_id_curriculum || ';' || p_id_idioma;

  INSERT INTO idioma_cv ("ID_IDIOMA_CV","NIVELL_ESCRIT","NIVELL_PARLAT","ID_CURRICULUM","ID_IDIOMA")
	VALUES (id_idioma_cv_nextval,p_nivell_escrit,p_nivell_parlat,p_id_curriculum,p_id_idioma);

  dbms_output.put_line('1 idioma currculum creat');
	sp_i_logbd('sp_i_idioma_cv',parametres,hora_inici,sysdate,sqlerrm);

  COMMIT;
  EXCEPTION
   WHEN OTHERS THEN 
      ROLLBACK;
      DBMS_OUTPUT.PUT_LINE(sqlerrm);
      sp_i_logbd('sp_i_idioma_cv',parametres,hora_inici,sysdate,sqlerrm);
END;
/

--
-- Definition for procedure SP_S_IDIOMA_CV
--
CREATE OR REPLACE PROCEDURE sp_s_idioma_cv(
    p_id_idioma_cv IN idioma_cv.id_idioma_cv%TYPE)
IS
  hora_inici logbd.hora_inici%TYPE;
  p_nivell_escrit idioma_cv.nivell_escrit%TYPE;
  p_nivell_parlat idioma_cv.nivell_parlat%TYPE;
  p_id_curriculum idioma_cv.id_curriculum%TYPE;
  p_id_idioma idioma_cv.id_idioma%TYPE;
  rec_idioma_cv idioma_cv%ROWTYPE;
  
  parametres logbd.param_procediment%TYPE;
	  
BEGIN
 
  SELECT SYSDATE INTO hora_inici FROM DUAL;

  SELECT * INTO rec_idioma_cv FROM idioma_cv
  WHERE id_idioma_cv = p_id_idioma_cv;

  DBMS_OUTPUT.PUT_LINE('ID IDIOMA CURRICULUM:' || rec_idioma_cv.id_idioma_cv || ' ' || 'NIVELL ESCRIT:' || rec_idioma_cv.nivell_escrit || ' ' || 'NIVELL PARLAT:' || rec_idioma_cv.nivell_parlat || ' ' || 'ID CURRICULUM:' ||
                        rec_idioma_cv.id_curriculum || ' ' || 'ID_IDIOMA:' || rec_idioma_cv.id_idioma);
  sp_i_logbd('sp_s_idioma_cv',p_id_idioma_cv,hora_inici,sysdate,sqlerrm);
  COMMIT;

  EXCEPTION
    WHEN NO_DATA_FOUND THEN
    DBMS_OUTPUT.PUT_LINE('Registre no trobat');
    sp_i_logbd('sp_s_idioma_cv',p_id_idioma_cv,hora_inici,sysdate,sqlerrm);
END;
/

--
-- Definition for procedure SP_D_IDIOMA_CV
--
CREATE OR REPLACE PROCEDURE sp_d_idioma_cv(
		p_id_idioma_cv IN idioma_cv.id_idioma_cv%TYPE)
IS
    hora_inici logbd.hora_inici%TYPE;
    id_idioma_cv idioma_cv.id_idioma_cv%TYPE;
     
BEGIN
  SELECT SYSDATE INTO hora_inici FROM DUAL;
  
  SELECT id_idioma_cv INTO id_idioma_cv FROM idioma_cv 
  WHERE id_idioma_cv = p_id_idioma_cv;

  DELETE idioma_cv WHERE id_idioma_cv = p_id_idioma_cv;
  DBMS_OUTPUT.PUT_LINE('Registre idioma_cv esborrat');
  sp_i_logbd('sp_d_idioma_cv',p_id_idioma_cv,hora_inici,sysdate,sqlerrm);
  COMMIT;
 
  EXCEPTION
     WHEN NO_DATA_FOUND THEN
       DBMS_OUTPUT.PUT_LINE('Registre no trobat');
       sp_i_logbd('sp_d_idioma_cv',p_id_idioma_cv,hora_inici,sysdate,sqlerrm);
     WHEN OTHERS THEN 
       ROLLBACK;
       DBMS_OUTPUT.PUT_LINE(sqlerrm);
       sp_i_logbd('sp_d_idioma_cv',p_id_idioma_cv,hora_inici,sysdate,sqlerrm);
END;
/

--
-- Definition for procedure SP_U_IDIOMA_CV
--
CREATE OR REPLACE PROCEDURE sp_u_idioma_cv(
   p_id_idioma_cv IN idioma_cv.id_idioma_cv%TYPE,
   p_nivell_escrit IN idioma_cv.nivell_escrit%TYPE,
   p_nivell_parlat IN idioma_cv.nivell_parlat%TYPE,
   p_id_curriculum IN idioma_cv.id_curriculum%TYPE,
   p_id_idioma IN idioma_cv.id_idioma%TYPE)

     
IS
  hora_inici logbd.hora_inici%TYPE;
	rec_idioma_cv idioma_cv%ROWTYPE;
  parametres logbd.param_procediment%TYPE;
  
BEGIN

   SELECT SYSDATE INTO hora_inici FROM DUAL;

   parametres:= p_id_idioma_cv || ';' || p_nivell_escrit || ';' || p_nivell_parlat || ';' || p_id_curriculum || ';' || p_id_idioma;

   SELECT * INTO rec_idioma_cv FROM idioma_cv 
   WHERE id_idioma_cv = p_id_idioma_cv;
      
   IF p_nivell_escrit IS NOT NULL THEN rec_idioma_cv.nivell_escrit:= p_nivell_escrit;
   END IF;
   IF p_nivell_parlat IS NOT NULL THEN rec_idioma_cv.nivell_parlat:= p_nivell_parlat;
   END IF;
   IF p_id_curriculum IS NOT NULL THEN rec_idioma_cv.id_curriculum:= p_id_curriculum;
   END IF;
   IF p_id_idioma IS NOT NULL THEN rec_idioma_cv.id_idioma:= p_id_idioma;
   END IF;
   
   UPDATE idioma_cv SET ROW = rec_idioma_cv
   WHERE id_idioma_cv = p_id_idioma_cv;
  
   dbms_output.put_line('idioma curroculum actualitzat');
   sp_i_logbd('sp_u_idioma_cv',parametres,hora_inici,sysdate,sqlerrm);
   COMMIT;
  
   EXCEPTION
      WHEN NO_DATA_FOUND THEN
         DBMS_OUTPUT.PUT_LINE('Registre no trobat');
         sp_i_logbd('sp_u_idioma_cv',parametres,hora_inici,sysdate,sqlerrm);
      WHEN OTHERS THEN 
         ROLLBACK;
         DBMS_OUTPUT.PUT_LINE(sqlerrm);
         sp_i_logbd('sp_u_idioma_cv',parametres,hora_inici,sysdate,sqlerrm);
END;
/

--
-- Definition for procedure SP_I_IDIOMA_OFERTA
--
CREATE OR REPLACE PROCEDURE sp_i_idioma_oferta(
   p_nivell_escrit IN idioma_oferta.nivell_escrit%TYPE,
   p_nivell_parlat IN idioma_oferta.nivell_parlat%TYPE,
   p_id_oferta IN idioma_oferta.id_oferta%TYPE,
   p_id_idioma IN idioma_oferta.id_idioma%TYPE)

IS
    id_idioma_oferta_nextval idioma_oferta.id_idioma_oferta%TYPE;
    hora_inici logbd.hora_inici%TYPE;
    parametres logbd.param_procediment%TYPE;
 
BEGIN

  SELECT SYSDATE INTO hora_inici FROM DUAL;
  
  id_idioma_oferta_nextval:= s_idioma_oferta.nextval;
  parametres:= id_idioma_oferta_nextval || ';' || p_nivell_escrit || ';' || p_nivell_parlat || ';' || p_id_oferta || ';' || p_id_idioma;

  INSERT INTO idioma_oferta ("ID_IDIOMA_OFERTA","NIVELL_ESCRIT","NIVELL_PARLAT","ID_OFERTA","ID_IDIOMA")
	VALUES (id_idioma_oferta_nextval,p_nivell_escrit,p_nivell_parlat,p_id_oferta,p_id_idioma);

  dbms_output.put_line('1 idioma oferta creat');
	sp_i_logbd('sp_i_idioma_oferta',parametres,hora_inici,sysdate,sqlerrm);

  COMMIT;
  EXCEPTION
   WHEN OTHERS THEN 
      ROLLBACK;
      DBMS_OUTPUT.PUT_LINE(sqlerrm);
      sp_i_logbd('sp_i_idioma_oferta',parametres,hora_inici,sysdate,sqlerrm);
END;
/

--
-- Definition for procedure SP_D_IDIOMA_OFERTA
--
CREATE OR REPLACE PROCEDURE sp_d_idioma_oferta(
		p_id_idioma_oferta IN idioma_oferta.id_idioma_oferta%TYPE)
IS
    hora_inici logbd.hora_inici%TYPE;
    id_idioma_oferta idioma_oferta.id_idioma_oferta%TYPE;
     
BEGIN
  SELECT SYSDATE INTO hora_inici FROM DUAL;
  
  SELECT id_idioma_oferta INTO id_idioma_oferta FROM idioma_oferta 
  WHERE id_idioma_oferta = p_id_idioma_oferta;

  DELETE idioma_oferta WHERE id_idioma_oferta = p_id_idioma_oferta;
  DBMS_OUTPUT.PUT_LINE('Registre idioma_oferta esborrat');
  sp_i_logbd('sp_d_idioma_oferta',p_id_idioma_oferta,hora_inici,sysdate,sqlerrm);
  COMMIT;
 
  EXCEPTION
     WHEN NO_DATA_FOUND THEN
       DBMS_OUTPUT.PUT_LINE('Registre no trobat');
       sp_i_logbd('sp_d_idioma_oferta',p_id_idioma_oferta,hora_inici,sysdate,sqlerrm);
     WHEN OTHERS THEN 
       ROLLBACK;
       DBMS_OUTPUT.PUT_LINE(sqlerrm);
       sp_i_logbd('sp_d_idioma_oferta',p_id_idioma_oferta,hora_inici,sysdate,sqlerrm);
END;
/

--
-- Definition for procedure SP_S_IDIOMA_OFERTA
--
CREATE OR REPLACE PROCEDURE sp_s_idioma_oferta(
    p_id_idioma_oferta IN idioma_oferta.id_idioma_oferta%TYPE)
IS
  hora_inici logbd.hora_inici%TYPE;
  p_nivell_escrit idioma_oferta.nivell_escrit%TYPE;
  p_nivell_parlat idioma_oferta.nivell_parlat%TYPE;
  p_id_oferta idioma_oferta.id_oferta%TYPE;
  p_id_idioma idioma_oferta.id_idioma%TYPE;
  rec_idioma_oferta idioma_oferta%ROWTYPE;
  
  parametres logbd.param_procediment%TYPE;
	  
BEGIN
 
  SELECT SYSDATE INTO hora_inici FROM DUAL;

  SELECT * INTO rec_idioma_oferta FROM idioma_oferta
  WHERE id_idioma_oferta = p_id_idioma_oferta;

  DBMS_OUTPUT.PUT_LINE('ID IDIOMA OFERTA:' || rec_idioma_oferta.id_idioma_oferta || ' ' || 'NIVELL ESCRIT:' || rec_idioma_oferta.nivell_escrit || ' ' || 'NIVELL PARLAT:' || rec_idioma_oferta.nivell_parlat || ' ' ||
                       'ID OFERTA:' || rec_idioma_oferta.id_oferta || ' ' || 'ID_IDIOMA:' || rec_idioma_oferta.id_idioma);

  sp_i_logbd('sp_s_idioma_oferta',p_id_idioma_oferta,hora_inici,sysdate,sqlerrm);
  COMMIT;

  EXCEPTION
    WHEN NO_DATA_FOUND THEN
    DBMS_OUTPUT.PUT_LINE('Registre no trobat');
    sp_i_logbd('sp_s_idioma_oferta',p_id_idioma_oferta,hora_inici,sysdate,sqlerrm);
END;
/

--
-- Definition for procedure SP_U_IDIOMA_OFERTA
--
CREATE OR REPLACE PROCEDURE sp_u_idioma_oferta(
   p_id_idioma_oferta IN idioma_oferta.id_idioma_oferta%TYPE,
   p_nivell_escrit IN idioma_oferta.nivell_escrit%TYPE,
   p_nivell_parlat IN idioma_oferta.nivell_parlat%TYPE,
   p_id_oferta IN idioma_oferta.id_oferta%TYPE,
   p_id_idioma IN idioma_oferta.id_idioma%TYPE)

     
IS
  hora_inici logbd.hora_inici%TYPE;
	rec_idioma_oferta idioma_oferta%ROWTYPE;
  parametres logbd.param_procediment%TYPE;
  
BEGIN

   SELECT SYSDATE INTO hora_inici FROM DUAL;

   parametres:= p_id_idioma_oferta || ';' || p_nivell_escrit || ';' || p_nivell_parlat || ';' || p_id_oferta || ';' || p_id_idioma;

   SELECT * INTO rec_idioma_oferta FROM idioma_oferta 
   WHERE id_idioma_oferta = p_id_idioma_oferta;
      
   IF p_nivell_escrit IS NOT NULL THEN rec_idioma_oferta.nivell_escrit:= p_nivell_escrit;
   END IF;
   IF p_nivell_parlat IS NOT NULL THEN rec_idioma_oferta.nivell_parlat:= p_nivell_parlat;
   END IF;
   IF p_id_oferta IS NOT NULL THEN rec_idioma_oferta.id_oferta:= p_id_oferta;
   END IF;
   IF p_id_idioma IS NOT NULL THEN rec_idioma_oferta.id_idioma:= p_id_idioma;
   END IF;
   
   UPDATE idioma_oferta SET ROW = rec_idioma_oferta
   WHERE id_idioma_oferta = p_id_idioma_oferta;
  
   dbms_output.put_line('Idioma oferta actualitzat');
   sp_i_logbd('sp_u_idioma_oferta',parametres,hora_inici,sysdate,sqlerrm);
   COMMIT;
  
   EXCEPTION
      WHEN NO_DATA_FOUND THEN
         DBMS_OUTPUT.PUT_LINE('Registre no trobat');
         sp_i_logbd('sp_u_idioma_oferta',parametres,hora_inici,sysdate,sqlerrm);
      WHEN OTHERS THEN 
         ROLLBACK;
         DBMS_OUTPUT.PUT_LINE(sqlerrm);
         sp_i_logbd('sp_u_idioma_oferta',parametres,hora_inici,sysdate,sqlerrm);
END;
/

--
-- Definition for procedure SP_S_LOGBD
--
CREATE OR REPLACE PROCEDURE sp_s_Logbd(
    p_data_ini IN Logbd.hora_inici%TYPE,
    p_data_fi IN Logbd.hora_fi%TYPE)
IS
    hora_inici logbd.hora_inici%TYPE;
    v_procediment LOGBD.PROCEDIMENT%TYPE;
		v_param_procediment LOGBD.PARAM_PROCEDIMENT%TYPE;
		v_hora_inici LOGBD.HORA_INICI%TYPE;
		v_hora_fi LOGBD.HORA_FI%TYPE;
		v_resultat LOGBD.RESULTAT%TYPE;
    CURSOR r_cursor IS
     SELECT * FROM Logbd
     WHERE to_date(hora_inici) >= p_data_ini and to_date(hora_inici) <= p_data_fi ORDER BY id_logbd;

  
BEGIN
 
 SELECT SYSDATE INTO hora_inici FROM DUAL;
  
 FOR r_logbd IN r_cursor LOOP
      DBMS_OUTPUT.PUT_LINE(r_logbd.id_logbd || ' ' || r_logbd.procediment || ' ' || r_logbd.param_procediment || ' ' ||
                       r_logbd.hora_inici || ' ' || r_logbd.hora_fi || ' ' || r_logbd.resultat);
 END LOOP;
 
 sp_i_logbd('sp_s_Logbd',p_data_ini || ';' || p_data_fi,hora_inici,sysdate,sqlerrm);

 EXCEPTION
    WHEN OTHERS THEN
    sp_i_logbd('sp_s_Logbd',p_data_ini || ';' || p_data_fi,hora_inici,sysdate,sqlerrm);
END;
/

--
-- Definition for procedure SP_D_LOGBD
--
CREATE OR REPLACE PROCEDURE sp_d_LogBd(
		p_id_LogBd IN LogBd.ID_LogBd%TYPE)
IS
    hora_inici logbd.hora_inici%TYPE;
    codi_LogBd LogBd.id_LogBd%TYPE;
      
BEGIN
  SELECT SYSDATE INTO hora_inici FROM DUAL;
  
  SELECT id_LogBd INTO codi_LogBd FROM LogBd 
  WHERE id_LogBd = p_id_LogBd;

  DELETE LogBd WHERE ID_LogBd = p_id_LogBd;
  DBMS_OUTPUT.PUT_LINE('Registre LogBd esborrat');
  sp_i_logbd('sp_d_LogBd',p_id_LogBd,hora_inici,sysdate,sqlerrm);
  COMMIT;

  EXCEPTION
     WHEN NO_DATA_FOUND THEN
       DBMS_OUTPUT.PUT_LINE('Registre no trobat');
       sp_i_logbd('sp_d_LogBd',p_id_LogBd,hora_inici,sysdate,sqlerrm);
     WHEN OTHERS THEN 
       ROLLBACK;
       DBMS_OUTPUT.PUT_LINE(sqlerrm);
       sp_i_logbd('sp_d_LogBd',p_id_LogBd,hora_inici,sysdate,sqlerrm);
END;
/

--
-- Definition for procedure SP_Q_OFERTES_PENDENTS
--
CREATE OR REPLACE PROCEDURE sp_q_Ofertes_Pendents 
     
IS
  hora_inici logbd.hora_inici%TYPE;
   
  CURSOR r_cursor IS
      SELECT * FROM v_ofertes
		  WHERE data_oferta_coberta is null
      ORDER BY (data + prioritat)ASC;

BEGIN

  SELECT SYSDATE INTO hora_inici FROM DUAL;

  FOR r_oferta_empresa IN r_cursor LOOP
      dbms_output.put_line('ID OFERTA:' || r_oferta_empresa.id_oferta || ' ' || 'EMPRESA:' || r_oferta_empresa.nom_complet || ' ' || 'MUNICIPI:' || r_oferta_empresa.municipi || ' ' || 
                           'DATA:' || r_oferta_empresa.data || ' ' || 'HORES:' || r_oferta_empresa.hores || ' ' || 'PERIODICITAT:' || 
                            r_oferta_empresa.periodicitat || ' ' || 'TIPUS JORNADA:' || r_oferta_empresa.tipus_jornada || ' ' || 
                            'PERFIL:' || r_oferta_empresa.descripcio || ' ' || 'PLACES:' || r_oferta_empresa.num_places || ' ' ||
                            'PRIORITAT:' || r_oferta_empresa.prioritat);
  END LOOP;
  sp_i_logbd('sp_q_ofertes_pendents',null,hora_inici,sysdate,sqlerrm);

  EXCEPTION
     WHEN OTHERS THEN 
       DBMS_OUTPUT.PUT_LINE(sqlerrm);
       sp_i_logbd('sp_q_ofertes_pendents',null,hora_inici,sysdate,sqlerrm);
END;
/

--
-- Definition for procedure SP_Q_OFERTES_CADUCADES
--
CREATE OR REPLACE PROCEDURE sp_q_Ofertes_Caducades 
     
IS
  hora_inici logbd.hora_inici%TYPE;
  
  CURSOR r_cursor IS
      SELECT * FROM v_ofertes
		  WHERE (data_oferta_coberta is NULL) AND ((to_date(data) + prioritat) < to_date(sysdate))
      ORDER BY municipi;

BEGIN
 
  SELECT SYSDATE INTO hora_inici FROM DUAL;

  FOR r_oferta_empresa IN r_cursor LOOP
      dbms_output.put_line('ID OFERTA:' || r_oferta_empresa.id_oferta || ' ' || 'EMPRESA:' || r_oferta_empresa.nom_complet || ' ' || 'MUNICIPI:' || r_oferta_empresa.municipi || ' ' || 
                           'DATA:' || r_oferta_empresa.data || ' ' || 'HORES:' || r_oferta_empresa.hores || ' ' || 'PERIODICITAT:' || 
                            r_oferta_empresa.periodicitat || ' ' || 'TIPUS JORNADA:' || r_oferta_empresa.tipus_jornada || ' ' || 
                            'PERFIL:' || r_oferta_empresa.descripcio || ' ' || 'PLACES:' || r_oferta_empresa.num_places || ' ' ||
                            'PRIORITAT:' || r_oferta_empresa.prioritat);
  END LOOP;
  sp_i_logbd('sp_q_ofertes_caducades',null,hora_inici,sysdate,sqlerrm);

  EXCEPTION
     WHEN OTHERS THEN 
       DBMS_OUTPUT.PUT_LINE(sqlerrm);
       sp_i_logbd('sp_q_ofertes_caducades',null,hora_inici,sysdate,sqlerrm);
END;
/

--
-- Definition for procedure SP_Q_OFERTA_CANDIDATS
--
CREATE OR REPLACE PROCEDURE sp_q_Oferta_Candidats(
    p_id_oferta IN oferta.id_oferta%TYPE)
-- Troba pesones amb curriculum amb un perfil a l'experincia laboral coincideix amb el de l'oferta. 
IS
  hora_inici logbd.hora_inici%TYPE;
  v_id_perfil solicitud.id_perfil%TYPE;
  v_desc_perfil perfil.descripcio%TYPE;

  CURSOR r_cursor_perfils(codi_perfil IN perfil.id_perfil%TYPE) IS
      SELECT p.id_persona, p.id_perfil,c.dni, c.nom, c.cognom1,c.cognom2, c.municipi, c.telefon 
      FROM v_perfils_persona p ,persona c
      WHERE (p.id_persona = c.id_persona) AND
            (codi_perfil = p.id_perfil);
    
BEGIN

  SELECT SYSDATE INTO hora_inici FROM DUAL;

  SELECT p.id_perfil,p.descripcio INTO v_id_perfil,v_desc_perfil
  FROM v_ofertes v, solicitud s, perfil p
	WHERE (v.id_oferta = p_id_oferta)
        AND (v.id_solicitud = s.id_solicitud)
        AND (s.id_perfil = p.id_perfil)
        AND (data_oferta_coberta is null);

  dbms_output.put_line('OFERTA: ' || p_id_oferta || '     ' || v_id_perfil || '-' || v_desc_perfil);
  dbms_output.put_line('-------------------------------------------------------------------------------------------------------------');
  
  FOR r_perfils IN r_cursor_perfils(v_id_perfil) LOOP
        dbms_output.put_line('ID PERSONA:' || r_perfils.id_persona || ' ' || 'DNI:' || r_perfils.dni || ' ' || 'NOM:' || r_perfils.nom || ' ' || 
                         'COGNOM1:' || r_perfils.cognom1 || ' ' || 'COGNOM2:' || r_perfils.cognom2 || ' ' ||
                         'MUNICIPI:' || r_perfils.municipi || ' ' || 'TELEFON:' || r_perfils.telefon);
    
  END LOOP;

  sp_i_logbd('sp_q_oferta_candidats',p_id_oferta,hora_inici,sysdate,sqlerrm);

  EXCEPTION
     WHEN NO_DATA_FOUND THEN
       DBMS_OUTPUT.PUT_LINE('Oferta inexistent');
       sp_i_logbd('sp_q_oferta_candidats',p_id_oferta,hora_inici,sysdate,sqlerrm);
     WHEN OTHERS THEN 
       DBMS_OUTPUT.PUT_LINE(sqlerrm);
       sp_i_logbd('sp_q_oferta_candidats',p_id_oferta,hora_inici,sysdate,sqlerrm);
END;
/

--
-- Definition for procedure SP_Q_OFERTA_CANDIDATS_ENT
--
CREATE OR REPLACE PROCEDURE sp_q_Oferta_Candidats_Ent(
    p_id_oferta IN oferta.id_oferta%TYPE)
-- Troba persones amb curriculum amb un perfil a l'experincia laboral coincident amb el de l'oferta i que ja han fet l'entrevista, podent-se visualitzar la valoraci obtinguda.
IS
  hora_inici logbd.hora_inici%TYPE;
  v_id_perfil solicitud.id_perfil%TYPE;
  v_desc_perfil perfil.descripcio%TYPE;

  CURSOR r_cursor_perfils(codi_perfil IN perfil.id_perfil%TYPE) IS
      SELECT p.id_persona, p.id_perfil,c.dni, c.nom, c.cognom1,c.cognom2,
             c.municipi, c.telefon, ent.id_persona AS codi_persona, ent.valoracio
      FROM v_perfils_persona p ,persona c, entrevista ent
      WHERE (p.id_persona = c.id_persona) AND
            (codi_perfil = p.id_perfil) AND
            (c.id_persona = ent.id_persona);
    
BEGIN

  SELECT SYSDATE INTO hora_inici FROM DUAL;

  SELECT p.id_perfil,p.descripcio INTO v_id_perfil,v_desc_perfil
  FROM v_ofertes v, solicitud s, perfil p
	WHERE (v.id_oferta = p_id_oferta)
        AND (v.id_solicitud = s.id_solicitud)
        AND (s.id_perfil = p.id_perfil)
        AND (data_oferta_coberta is null);

  dbms_output.put_line('OFERTA: ' || p_id_oferta || '     ' || v_id_perfil || '-' || v_desc_perfil);
  dbms_output.put_line('---------------------------------------------------------------------------------------------------------------------------------');
  
  FOR r_perfils IN r_cursor_perfils(v_id_perfil) LOOP
        dbms_output.put_line('ID PERSONA:' || r_perfils.id_persona || ' ' || 'DNI:' || r_perfils.dni || ' ' || 'NOM:' || r_perfils.nom || ' ' || 
                         'COGNOM1:' || r_perfils.cognom1 || ' ' || 'COGNOM2:' || r_perfils.cognom2 || ' ' ||
                         'MUNICIPI:' || r_perfils.municipi || ' ' || 'TELEFON:' || r_perfils.telefon || ' ' || 'VALORACI ENTREVISTA:' || r_perfils.valoracio);
    
  END LOOP;

  sp_i_logbd('sp_q_oferta_candidats_ent',p_id_oferta,hora_inici,sysdate,sqlerrm);

  EXCEPTION
     WHEN NO_DATA_FOUND THEN
       DBMS_OUTPUT.PUT_LINE('Oferta inexistent');
       sp_i_logbd('sp_q_oferta_candidats_ent',p_id_oferta,hora_inici,sysdate,sqlerrm);
     WHEN OTHERS THEN 
       DBMS_OUTPUT.PUT_LINE(sqlerrm);
       sp_i_logbd('sp_q_oferta_candidats_ent',p_id_oferta,hora_inici,sysdate,sqlerrm);
END;
/

--
-- Definition for procedure SP_Q_OFERTA2DEMANDA
--
CREATE OR REPLACE PROCEDURE sp_q_Oferta2Demanda(
    p_id_demanda IN demanda.id_demanda%TYPE)
-- Troba totes les ofertes possibles per una demanda determinada

IS
  hora_inici logbd.hora_inici%TYPE;
  codi_demanda demanda.id_demanda%TYPE;
  desc_perfil perfil.descripcio%TYPE;
  id_perfil perfil.id_perfil%TYPE;
  
 CURSOR r_cursor(v_id_perfil IN perfil.id_perfil%TYPE) IS
      SELECT * FROM v_ofertes
		  WHERE data_oferta_coberta is null
      AND id_perfil = v_id_perfil;
           
BEGIN

  SELECT SYSDATE INTO hora_inici FROM DUAL;

  SELECT id_demanda,id_perfil,descripcio INTO codi_demanda,id_perfil,desc_perfil FROM v_demandes
  WHERE id_demanda = p_id_demanda;

  dbms_output.put_line('DEMANDA: ' || codi_demanda || '     ' || id_perfil || '-' || desc_perfil);
  dbms_output.put_line('-------------------------------------------------------------------------------------------------------------');
  
  FOR r_ofertes IN r_cursor(id_perfil) LOOP
        dbms_output.put_line('ID OFERTA:' || r_ofertes.id_persona || ' ' || 'EMPRESA:' || r_ofertes.id_persona || ' ' ||
                             'NIF:' || r_ofertes.dni || ' ' || 'NOM:' || r_ofertes.nom_complet || ' ' || 'MUNICIPI:' || r_ofertes.municipi);
  END LOOP;

  sp_i_logbd('sp_q_oferta2demanda',p_id_demanda,hora_inici,sysdate,sqlerrm);

  EXCEPTION
     WHEN NO_DATA_FOUND THEN
       DBMS_OUTPUT.PUT_LINE('Demanda inexistent');
       sp_i_logbd('sp_q_oferta2demanda',p_id_demanda,hora_inici,sysdate,sqlerrm);
     WHEN OTHERS THEN 
       DBMS_OUTPUT.PUT_LINE(sqlerrm);
       sp_i_logbd('sp_q_oferta2demanda',p_id_demanda,hora_inici,sysdate,sqlerrm);
END;
/

--
-- Definition for procedure SP_Q_DEMANDA2OFERTA
--
CREATE OR REPLACE PROCEDURE sp_q_Demanda2Oferta(
    p_id_oferta IN oferta.id_oferta%TYPE)
-- Troba totes les demandes possibles per una oferta determinada

IS
  hora_inici logbd.hora_inici%TYPE;

  codi_oferta oferta.id_oferta%TYPE;
  desc_perfil perfil.descripcio%TYPE;
  id_perfil perfil.id_perfil%TYPE;
  
 CURSOR r_cursor(v_id_perfil IN perfil.id_perfil%TYPE) IS
      SELECT * FROM v_demandes
		  WHERE id_perfil = v_id_perfil;
           
BEGIN

  SELECT SYSDATE INTO hora_inici FROM DUAL;

  SELECT id_oferta,id_perfil,descripcio INTO codi_oferta,id_perfil,desc_perfil FROM v_ofertes
  WHERE id_oferta = p_id_oferta;

  dbms_output.put_line('OFERTA: ' || codi_oferta || '     ' || id_perfil || '-' || desc_perfil);
  dbms_output.put_line('-------------------------------------------------------------------------------------------------------------');
  
  FOR r_demandes IN r_cursor(id_perfil) LOOP
        dbms_output.put_line('ID DEMANDA:' || r_demandes.id_persona || ' ' || 'ID PERSONA:' || r_demandes.id_persona || ' ' ||
                             'DNI:' || r_demandes.dni || ' ' || 'NOM:' || r_demandes.nom || ' ' || 'COGNOM1:' || r_demandes.cognom1 || ' ' ||
                             'COGNOM2:' || r_demandes.cognom2 || ' ' || 'MUNICIPI:' || r_demandes.municipi || ' ' || 'TELEFON: ' || r_demandes.telefon);
  END LOOP;

  sp_i_logbd('sp_q_demandes2oferta',p_id_oferta,hora_inici,sysdate,sqlerrm);

  EXCEPTION
     WHEN NO_DATA_FOUND THEN
       DBMS_OUTPUT.PUT_LINE('Oferta inexistent');
       sp_i_logbd('sp_q_demandes2oferta',p_id_oferta,hora_inici,sysdate,sqlerrm);
     WHEN OTHERS THEN 
       DBMS_OUTPUT.PUT_LINE(sqlerrm);
       sp_i_logbd('sp_q_demandes2oferta',p_id_oferta,hora_inici,sysdate,sqlerrm);
END;
/

--
-- Definition for procedure SP_Q_VALORA_ENTREVISTA
--
CREATE OR REPLACE PROCEDURE sp_q_Valora_Entrevista(
    p_id_Entrevista IN Entrevista.id_Entrevista%TYPE,
    p_valoracio IN entrevista.valoracio%TYPE)
    
IS
  hora_inici logbd.hora_inici%TYPE;
  codi_entrevista entrevista.id_entrevista%TYPE;
	parametres logbd.param_procediment%TYPE;
  
BEGIN

   SELECT SYSDATE INTO hora_inici FROM DUAL;

   parametres:= p_id_entrevista || ';' || p_valoracio;

   SELECT id_entrevista INTO codi_entrevista FROM Entrevista 
   WHERE id_Entrevista = p_id_Entrevista;
      
   IF p_valoracio IS NOT NULL THEN
      UPDATE entrevista SET valoracio=p_valoracio
      WHERE id_entrevista = p_id_entrevista;

      dbms_output.put_line('Entrevista actualitzada');
      sp_i_logbd('sp_q_ValoraEntrevista',parametres,hora_inici,sysdate,sqlerrm);
      COMMIT;
   END IF;
    
   EXCEPTION
      WHEN NO_DATA_FOUND THEN
         DBMS_OUTPUT.PUT_LINE('Entrevista no trobada');
         sp_i_logbd('sp_q_ValoraEntrevista',parametres,hora_inici,sysdate,sqlerrm);
      WHEN OTHERS THEN 
         ROLLBACK;
         DBMS_OUTPUT.PUT_LINE(sqlerrm);
         sp_i_logbd('sp_q_ValoraEntrevista',parametres,hora_inici,sysdate,sqlerrm);
END;
/

--
-- Definition for procedure SP_Q_OFERTA_COBERTA
--
CREATE OR REPLACE PROCEDURE sp_q_Oferta_Coberta(
    p_id_Oferta IN Oferta.id_Oferta%TYPE,
    p_data_oferta_coberta IN oferta.data_oferta_coberta%TYPE)
     
IS
  hora_inici logbd.hora_inici%TYPE;
	codi_oferta oferta.id_oferta%TYPE;
  parametres logbd.param_procediment%TYPE;
  
BEGIN

   SELECT SYSDATE INTO hora_inici FROM DUAL;

   parametres:= p_id_oferta || ';' || p_data_oferta_coberta;

   SELECT id_oferta INTO codi_oferta FROM Oferta 
   WHERE id_Oferta = p_id_Oferta;
      
   IF p_data_oferta_coberta IS NOT NULL THEN
     UPDATE Oferta SET data_oferta_coberta = p_data_oferta_coberta
     WHERE id_Oferta = p_id_Oferta;
  
     dbms_output.put_line('Oferta actualitzada');
     sp_i_logbd('sp_q_Oferta_Coberta',parametres,hora_inici,sysdate,sqlerrm);
   COMMIT;
   END IF;
  
   EXCEPTION
      WHEN NO_DATA_FOUND THEN
         DBMS_OUTPUT.PUT_LINE('Oferta inexistent');
         sp_i_logbd('sp_q_Oferta_Coberta',parametres,hora_inici,sysdate,sqlerrm);
      WHEN OTHERS THEN 
         ROLLBACK;
         DBMS_OUTPUT.PUT_LINE(sqlerrm);
         sp_i_logbd('sp_q_Oferta_Coberta',parametres,hora_inici,sysdate,sqlerrm);
END;
