
--
-- Definition for table AREA_LABORAL
--
CREATE TABLE AREA_LABORAL (
  ID_AREA_LABORAL NUMBER NOT NULL,
  DESCRIPCIO VARCHAR2(40 BYTE) NOT NULL,
  CONSTRAINT "AREA_LABORAL PK" PRIMARY KEY (ID_AREA_LABORAL))
TABLESPACE USERS
STORAGE (
  INITIAL 64K
  MAXEXTENTS UNLIMITED
)
LOGGING;

--
-- Definition for table CURRICULUM
--
CREATE TABLE CURRICULUM (
  ID_CURRICULUM NUMBER NOT NULL,
  DATA DATE NOT NULL,
  ID_PERSONA NUMBER NOT NULL,
  CONSTRAINT "CURRICULUM PK" PRIMARY KEY (ID_CURRICULUM))
TABLESPACE USERS
STORAGE (
  INITIAL 64K
  MAXEXTENTS UNLIMITED
)
LOGGING;

--
-- Definition for table LOGBD
--
CREATE TABLE LOGBD (
  ID_LOGBD NUMBER NOT NULL,
  PROCEDIMENT VARCHAR2(50 BYTE) NOT NULL,
  PARAM_PROCEDIMENT VARCHAR2(255 BYTE),
  HORA_INICI DATE NOT NULL,
  HORA_FI DATE NOT NULL,
  RESULTAT VARCHAR2(255 BYTE) NOT NULL,
  CONSTRAINT "LOGBD PK" PRIMARY KEY (ID_LOGBD))
TABLESPACE USERS
STORAGE (
  INITIAL 64K
  MAXEXTENTS UNLIMITED
)
LOGGING;

--
-- Definition for table TIPUS_TITULACIO
--
CREATE TABLE TIPUS_TITULACIO (
  ID_TIPUS_TITULACIO NUMBER NOT NULL,
  DESCRIPCIO VARCHAR2(40 BYTE) NOT NULL,
  CONSTRAINT "TIPUS_TITULACIO PK" PRIMARY KEY (ID_TIPUS_TITULACIO))
TABLESPACE USERS
STORAGE (
  INITIAL 64K
  MAXEXTENTS UNLIMITED
)
LOGGING;

--
-- Definition for table IDIOMA
--
CREATE TABLE IDIOMA (
  ID_IDIOMA NUMBER NOT NULL,
  DESCRIPCIO VARCHAR2(20 BYTE) NOT NULL,
  CONSTRAINT "IDIOMA PK" PRIMARY KEY (ID_IDIOMA))
TABLESPACE USERS
STORAGE (
  INITIAL 64K
  MAXEXTENTS UNLIMITED
)
LOGGING;

--
-- Definition for table PERSONA
--
CREATE TABLE PERSONA (
  ID_PERSONA NUMBER NOT NULL,
  TIPUS_PERSONA CHAR(1 BYTE) NOT NULL,
  DNI VARCHAR2(12 BYTE),
  NOM VARCHAR2(25 BYTE),
  COGNOM1 VARCHAR2(30 BYTE),
  COGNOM2 VARCHAR2(30 BYTE),
  NOM_COMPLET VARCHAR2(85 BYTE),
  DATA_NAIXEMENT DATE,
  ADRECA VARCHAR2(60 BYTE),
  MUNICIPI VARCHAR2(40 BYTE),
  PROVINCIA VARCHAR2(25 BYTE),
  PAIS VARCHAR2(25 BYTE),
  EMAIL VARCHAR2(40 BYTE),
  WEB VARCHAR2(40 BYTE),
  TELEFON VARCHAR2(15 BYTE),
  CONSTRAINT CK_TIPUS_PERSONA CHECK (TIPUS_PERSONA IN ('F','J')),
  CONSTRAINT "PERSONA PK" PRIMARY KEY (ID_PERSONA))
TABLESPACE USERS
STORAGE (
  INITIAL 64K
  MAXEXTENTS UNLIMITED
)
LOGGING;

--
-- Definition for table BRANCA
--
CREATE TABLE BRANCA (
  ID_BRANCA NUMBER NOT NULL,
  DESCRIPCIO VARCHAR2(40 BYTE) NOT NULL,
  ID_TIPUS_TITULACIO NUMBER NOT NULL,
  CONSTRAINT "BRANCA PK" PRIMARY KEY (ID_BRANCA),
  CONSTRAINT FK_BRANCA_FK_TIPUS_TITULACIO FOREIGN KEY (ID_TIPUS_TITULACIO)
    REFERENCES TIPUS_TITULACIO(ID_TIPUS_TITULACIO))
TABLESPACE USERS
STORAGE (
  INITIAL 64K
  MAXEXTENTS UNLIMITED
)
LOGGING;

--
-- Definition for table PERFIL
--
CREATE TABLE PERFIL (
  ID_PERFIL NUMBER NOT NULL,
  DESCRIPCIO VARCHAR2(40 BYTE) NOT NULL,
  ID_AREA_LABORAL NUMBER NOT NULL,
  CONSTRAINT "PERFIL PK" PRIMARY KEY (ID_PERFIL),
  CONSTRAINT FK_PERFIL_FK_AREA_LABORAL FOREIGN KEY (ID_AREA_LABORAL)
    REFERENCES AREA_LABORAL(ID_AREA_LABORAL))
TABLESPACE USERS
STORAGE (
  INITIAL 64K
  MAXEXTENTS UNLIMITED
)
LOGGING;

--
-- Definition for table IDIOMA_CV
--
CREATE TABLE IDIOMA_CV (
  ID_IDIOMA_CV NUMBER NOT NULL,
  NIVELL_ESCRIT NUMBER NOT NULL,
  NIVELL_PARLAT NUMBER NOT NULL,
  ID_CURRICULUM NUMBER NOT NULL,
  ID_IDIOMA NUMBER NOT NULL,
  CONSTRAINT CK_NIVELL_ESCRIT_IDIOMA_CV CHECK (NIVELL_ESCRIT >= 0 AND NIVELL_ESCRIT <= 10),
  CONSTRAINT CK_NIVELL_PARLAT_IDIOMA_CV CHECK (NIVELL_PARLAT >= 0 AND NIVELL_PARLAT <= 10),
  CONSTRAINT "IDIOMA_CV PK" PRIMARY KEY (ID_IDIOMA_CV),
  CONSTRAINT FK_CURRICULUM_FK_IDIOMA_CV FOREIGN KEY (ID_CURRICULUM)
    REFERENCES CURRICULUM(ID_CURRICULUM),
  CONSTRAINT FK_IDIOMA_IDIOMA_CV FOREIGN KEY (ID_IDIOMA)
    REFERENCES IDIOMA(ID_IDIOMA))
TABLESPACE USERS
STORAGE (
  INITIAL 64K
  MAXEXTENTS UNLIMITED
)
LOGGING;

--
-- Definition for table EXP_LABORAL
--
CREATE TABLE EXP_LABORAL (
  ID_EXP_LABORAL NUMBER NOT NULL,
  DATA_INICI DATE,
  DATA_FI DATE,
  ID_PERFIL NUMBER NOT NULL,
  ID_CURRICULUM NUMBER NOT NULL,
  ID_PERSONA NUMBER NOT NULL,
  CONSTRAINT "EXP_LABORAL PK" PRIMARY KEY (ID_EXP_LABORAL),
  CONSTRAINT FK_CURRICULUM_FK_EXP_LABORAL FOREIGN KEY (ID_CURRICULUM)
    REFERENCES CURRICULUM(ID_CURRICULUM),
  CONSTRAINT FK_EXP_LABORAL_FK_PERFIL FOREIGN KEY (ID_PERFIL)
    REFERENCES PERFIL(ID_PERFIL),
  CONSTRAINT FK_EXP_LABORAL_FK_PERSONA FOREIGN KEY (ID_PERSONA)
    REFERENCES PERSONA(ID_PERSONA))
TABLESPACE USERS
STORAGE (
  INITIAL 64K
  MAXEXTENTS UNLIMITED
)
LOGGING;

--
-- Definition for table SOLICITUD
--
CREATE TABLE SOLICITUD (
  ID_SOLICITUD NUMBER NOT NULL,
  DATA DATE,
  HORES NUMBER(6, 2),
  SALARI NUMBER(10, 2),
  EXPERIENCIA CHAR(1 BYTE) DEFAULT 'N' NOT NULL,
  PERIODICITAT CHAR(1 BYTE),
  TIPUS_JORNADA CHAR(2 BYTE),
  ID_PERFIL NUMBER NOT NULL,
  ID_PERSONA NUMBER NOT NULL,
  CONSTRAINT CK_PERIODICITAT CHECK (PERIODICITAT IN ('D','S','M')),
  CONSTRAINT CK_SALARI CHECK (SALARI > 0),
  CONSTRAINT CK_TIPUS_JORNADA CHECK (TIPUS_JORNADA IN ('C','P','PM','PT')),
  CONSTRAINT CK_EXPERIENCIA CHECK (EXPERIENCIA IN ('S','N')),
  CONSTRAINT "SOLICITUD PK" PRIMARY KEY (ID_SOLICITUD),
  CONSTRAINT FK_SOLICITUD_FK_PERFIL FOREIGN KEY (ID_PERFIL)
    REFERENCES PERFIL(ID_PERFIL),
  CONSTRAINT FK_SOLICITUD_FK_PERSONA FOREIGN KEY (ID_PERSONA)
    REFERENCES PERSONA(ID_PERSONA))
TABLESPACE USERS
STORAGE (
  INITIAL 64K
  MAXEXTENTS UNLIMITED
)
LOGGING;

--
-- Definition for table TITULACIO
--
CREATE TABLE TITULACIO (
  ID_TITULACIO NUMBER NOT NULL,
  DESCRIPCIO VARCHAR2(40 BYTE) NOT NULL,
  ID_BRANCA NUMBER NOT NULL,
  CONSTRAINT "TITULACIO PK" PRIMARY KEY (ID_TITULACIO),
  CONSTRAINT FK_TITULACIO_FK_BRANCA FOREIGN KEY (ID_BRANCA)
    REFERENCES BRANCA(ID_BRANCA))
TABLESPACE USERS
STORAGE (
  INITIAL 64K
  MAXEXTENTS UNLIMITED
)
LOGGING;

--
-- Definition for table DEMANDA
--
CREATE TABLE DEMANDA (
  ID_DEMANDA NUMBER NOT NULL,
  ID_SOLICITUD NUMBER NOT NULL,
  CONSTRAINT "DEMANDA PK" PRIMARY KEY (ID_DEMANDA),
  CONSTRAINT FK_DEMANDA_FK_SOLICITUD FOREIGN KEY (ID_SOLICITUD)
    REFERENCES SOLICITUD(ID_SOLICITUD))
TABLESPACE USERS
STORAGE (
  INITIAL 64K
  MAXEXTENTS UNLIMITED
)
LOGGING;

CREATE UNIQUE INDEX DEMANDA__IDX ON DEMANDA (ID_SOLICITUD)
TABLESPACE USERS
STORAGE (
  INITIAL 64K
  MAXEXTENTS UNLIMITED
)
LOGGING;

--
-- Definition for table FORMACIO
--
CREATE TABLE FORMACIO (
  ID_FORMACIO NUMBER NOT NULL,
  DATA_INICI DATE,
  DATA_FI DATE,
  ID_CURRICULUM NUMBER NOT NULL,
  ID_TITULACIO NUMBER NOT NULL,
  ID_PERSONA NUMBER NOT NULL,
  CONSTRAINT "FORMACIO PK" PRIMARY KEY (ID_FORMACIO),
  CONSTRAINT FK_CURRICULUM_FK_FORMACIO FOREIGN KEY (ID_CURRICULUM)
    REFERENCES CURRICULUM(ID_CURRICULUM),
  CONSTRAINT FK_FORMACIO_FK_TITULACIO FOREIGN KEY (ID_TITULACIO)
    REFERENCES TITULACIO(ID_TITULACIO),
  CONSTRAINT FK_PERSONA_FK_FORMACIO FOREIGN KEY (ID_PERSONA)
    REFERENCES PERSONA(ID_PERSONA))
TABLESPACE USERS
STORAGE (
  INITIAL 64K
  MAXEXTENTS UNLIMITED
)
LOGGING;

--
-- Definition for table OFERTA
--
CREATE TABLE OFERTA (
  ID_OFERTA NUMBER NOT NULL,
  NUM_PLACES NUMBER NOT NULL,
  PRIORITAT NUMBER NOT NULL,
  CONEIX_INFORMATICS CHAR(1 BYTE),
  DATA_OFERTA_COBERTA DATE,
  ID_SOLICITUD NUMBER NOT NULL,
  ID_TITULACIO NUMBER,
  MUNICIPI VARCHAR2(40 BYTE) NOT NULL,
  PROVINCIA VARCHAR2(25 BYTE) NOT NULL,
  PAIS VARCHAR2(25 BYTE) NOT NULL,
  CONSTRAINT CK_CONEIX_INFORMATICS CHECK (CONEIX_INFORMATICS IN (NULL,'B','M','A')),
  CONSTRAINT "OFERTA PK" PRIMARY KEY (ID_OFERTA),
  CONSTRAINT FK_OFERTA_FK_SOLICITUD FOREIGN KEY (ID_SOLICITUD)
    REFERENCES SOLICITUD(ID_SOLICITUD),
  CONSTRAINT FK_OFERTA_FK_TITULACIO FOREIGN KEY (ID_TITULACIO)
    REFERENCES TITULACIO(ID_TITULACIO))
TABLESPACE USERS
STORAGE (
  INITIAL 64K
  MAXEXTENTS UNLIMITED
)
LOGGING;

CREATE UNIQUE INDEX OFERTA__IDX ON OFERTA (ID_SOLICITUD)
TABLESPACE USERS
STORAGE (
  INITIAL 64K
  MAXEXTENTS UNLIMITED
)
LOGGING;

--
-- Definition for table ENTREVISTA
--
CREATE TABLE ENTREVISTA (
  ID_ENTREVISTA NUMBER NOT NULL,
  DATA DATE NOT NULL,
  VALORACIO NUMBER,
  EXPERIENCIA CHAR(1 BYTE),
  DATA_ACCEPTACIO DATE,
  ID_OFERTA NUMBER NOT NULL,
  ID_PERSONA NUMBER NOT NULL,
  CONSTRAINT CK_VALORACIO CHECK (VALORACIO >= 0 AND VALORACIO <= 10),
  CONSTRAINT "ENTREVISTA PK" PRIMARY KEY (ID_ENTREVISTA),
  CONSTRAINT FK_ENTREVISTA_FK_PERSONA FOREIGN KEY (ID_PERSONA)
    REFERENCES PERSONA(ID_PERSONA),
  CONSTRAINT FK_OFERTA_FK_ENTREVISTA FOREIGN KEY (ID_OFERTA)
    REFERENCES OFERTA(ID_OFERTA))
TABLESPACE USERS
STORAGE (
  INITIAL 64K
  MAXEXTENTS UNLIMITED
)
LOGGING;

--
-- Definition for table IDIOMA_OFERTA
--
CREATE TABLE IDIOMA_OFERTA (
  ID_IDIOMA_OFERTA NUMBER NOT NULL,
  NIVELL_ESCRIT NOT NULL,
  NIVELL_PARLAT NOT NULL,
  ID_OFERTA NUMBER NOT NULL,
  ID_IDIOMA NUMBER NOT NULL,
  CONSTRAINT CK_NIVELL_ESCRIT CHECK (NIVELL_ESCRIT >= 0 AND NIVELL_ESCRIT <= 10),
  CONSTRAINT CK_NIVELL_PARLAT CHECK (NIVELL_PARLAT >= 0 AND NIVELL_PARLAT <= 10),
  CONSTRAINT "IDIOMA_OFERTA PK" PRIMARY KEY (ID_IDIOMA_OFERTA),
  CONSTRAINT FK_IDIOMA_FK_IDIOMA_OFERTA FOREIGN KEY (ID_IDIOMA)
    REFERENCES IDIOMA(ID_IDIOMA),
  CONSTRAINT FK_OFERTA_FK_IDIOMA_OFERTA FOREIGN KEY (ID_OFERTA)
    REFERENCES OFERTA(ID_OFERTA))
TABLESPACE USERS
STORAGE (
  INITIAL 64K
  MAXEXTENTS UNLIMITED
)
LOGGING;