
--
-- Definition for procedure SP_ETL_D_EMPRESA
--
CREATE OR REPLACE PROCEDURE SP_ETL_D_EMPRESA 
    
-- Carrega les empreses de PFC.Persona de Tipus 'J' a PFCDWH.D_Empresa

IS

  codi_empresa pfc.persona.id_persona%TYPE;
  nom_empresa pfc.persona.nom_complet%TYPE;
  exist_empresa integer;
  hora_inici pfc.logbd.hora_inici%TYPE;
    
 CURSOR r_cursor IS
      SELECT id_persona,nom_complet
      FROM pfc.persona 
      WHERE pfc.persona.tipus_persona='J';
           
BEGIN
  SELECT SYSDATE INTO hora_inici FROM DUAL;

  OPEN r_cursor;
  LOOP
    FETCH r_cursor INTO codi_empresa,nom_empresa;
    EXIT WHEN r_cursor%NOTFOUND;
    
    SELECT count(*) INTO exist_empresa FROM D_EMPRESA WHERE id_empresa = codi_empresa;
    IF exist_empresa <> 0 THEN
			UPDATE D_EMPRESA SET NOM = nom_empresa WHERE id_empresa = codi_empresa;
	  ELSE  
	  	INSERT INTO D_EMPRESA ("ID_EMPRESA","NOM") VALUES (codi_empresa,nom_empresa);
	  END IF;
  END LOOP;
  CLOSE r_cursor;
 
  pfc.sp_i_logbd('sp_etl_d_empresa',NULL,hora_inici,sysdate,sqlerrm);

  EXCEPTION
     WHEN NO_DATA_FOUND THEN
       DBMS_OUTPUT.PUT_LINE('Taula origen sense dades');
       pfc.sp_i_logbd('sp_etl_d_empresa',NULL,hora_inici,sysdate,sqlerrm);
     WHEN OTHERS THEN 
       DBMS_OUTPUT.PUT_LINE(sqlerrm);
       pfc.sp_i_logbd('sp_etl_d_empresa',NULL,hora_inici,sysdate,sqlerrm);

END;
/

--
-- Definition for procedure SP_ETL_D_PERFIL
--
CREATE OR REPLACE PROCEDURE SP_ETL_D_PERFIL 
    
-- Carrega els perfil de PFC.Perfils a PFCDWH.D_Perfil

IS
  hora_inici pfc.logbd.hora_inici%TYPE;

  codi_perfil pfc.perfil.id_perfil%TYPE;
  desc_perfil pfc.perfil.descripcio%TYPE;
  exist_perfil integer;
    
 CURSOR r_cursor IS
      SELECT id_perfil,descripcio FROM pfc.perfil;
           
BEGIN

  SELECT SYSDATE INTO hora_inici FROM DUAL;

  OPEN r_cursor;
  LOOP
    FETCH r_cursor INTO codi_perfil,desc_perfil;
    EXIT WHEN r_cursor%NOTFOUND;
		SELECT count(*) INTO exist_perfil FROM d_perfil WHERE id_perfil = codi_perfil;
		IF exist_perfil <> 0 THEN
			UPDATE d_perfil SET descripcio = desc_perfil WHERE id_perfil = codi_perfil;
		ELSE  
			INSERT INTO d_perfil ("ID_PERFIL","DESCRIPCIO") VALUES (codi_perfil,desc_perfil);
		END IF;
  END LOOP;
  CLOSE r_cursor;
  pfc.sp_i_logbd('sp_etl_d_perfil',NULL,hora_inici,sysdate,sqlerrm);

  EXCEPTION
     WHEN NO_DATA_FOUND THEN
       DBMS_OUTPUT.PUT_LINE('Taula origen sense dades');
       pfc.sp_i_logbd('sp_etl_d_perfil',NULL,hora_inici,sysdate,sqlerrm);
     WHEN OTHERS THEN 
       DBMS_OUTPUT.PUT_LINE(sqlerrm);
       pfc.sp_i_logbd('sp_etl_d_perfil',NULL,hora_inici,sysdate,sqlerrm);
END;
/

--
-- Definition for procedure SP_ETL_D_LLOC
--
CREATE OR REPLACE PROCEDURE SP_ETL_D_LLOC 
    
-- Carrega els llocs (municipi, provincia, pais) de les ofertes PFCDWH.D_Lloc

IS
  hora_inici pfc.logbd.hora_inici%TYPE;

  lloc_municipi pfc.oferta.municipi%TYPE;
  lloc_provincia pfc.oferta.provincia%TYPE;
  lloc_pais pfc.oferta.pais%TYPE;
  exist_municipi integer;
     
 CURSOR r_cursor IS
      SELECT DISTINCT municipi,provincia,pais FROM pfc.oferta;
           
BEGIN

  SELECT SYSDATE INTO hora_inici FROM DUAL;

  OPEN r_cursor;
  LOOP
    FETCH r_cursor INTO lloc_municipi,lloc_provincia,lloc_pais;
    EXIT WHEN r_cursor%NOTFOUND;
    
    SELECT count(*) INTO exist_municipi FROM d_lloc WHERE municipi = lloc_municipi;
		IF exist_municipi <> 0 THEN
			UPDATE d_lloc SET municipi=lloc_municipi,provincia=lloc_provincia,pais=lloc_pais 
      WHERE municipi = lloc_municipi;
		ELSE  
			INSERT INTO d_lloc ("ID_LLOC","MUNICIPI","PROVINCIA","PAIS") VALUES(s_d_lloc.nextval,lloc_municipi, lloc_provincia, lloc_pais);
		END IF;
  END LOOP;
  CLOSE r_cursor;

  pfc.sp_i_logbd('sp_etl_d_lloc',NULL,hora_inici,sysdate,sqlerrm);

  EXCEPTION
     WHEN NO_DATA_FOUND THEN
       DBMS_OUTPUT.PUT_LINE('Taula origen sense dades');
       pfc.sp_i_logbd('sp_etl_d_lloc',NULL,hora_inici,sysdate,sqlerrm);
     WHEN OTHERS THEN 
       DBMS_OUTPUT.PUT_LINE(sqlerrm);
       pfc.sp_i_logbd('sp_etl_d_lloc',NULL,hora_inici,sysdate,sqlerrm);
END;
/

--
-- Definition for procedure SP_ETL_D_ATRIBUT
--
CREATE OR REPLACE PROCEDURE SP_ETL_D_ATRIBUT 
    
-- Inserta atribut experiencia
IS
  hora_inici pfc.logbd.hora_inici%TYPE;
  temps_experiencia d_atribut.experiencia%TYPE;
  exist_atr integer;

CURSOR r_cursor IS
  SELECT DISTINCT experiencia FROM pfc.solicitud;
             
BEGIN

  SELECT SYSDATE INTO hora_inici FROM DUAL;
  
  OPEN r_cursor;
  LOOP
    FETCH r_cursor INTO temps_experiencia;
    EXIT WHEN r_cursor%NOTFOUND;

    SELECT count(*) into exist_atr FROM d_atribut WHERE experiencia = temps_experiencia;
    IF exist_atr = 0 THEN
      	INSERT INTO d_atribut ("ID_ATRIBUT","EXPERIENCIA") VALUES (s_d_atribut.nextval, temps_experiencia);
    END IF;
  END LOOP;
  CLOSE r_cursor;
  pfc.sp_i_logbd('sp_etl_d_atribut',NULL,hora_inici,sysdate,sqlerrm);

  EXCEPTION
     WHEN OTHERS THEN 
       DBMS_OUTPUT.PUT_LINE(sqlerrm);
       pfc.sp_i_logbd('sp_etl_d_atribut',NULL,hora_inici,sysdate,sqlerrm);
END;
/

--
-- Definition for procedure SP_ETL_D_TEMPS
--
CREATE OR REPLACE PROCEDURE SP_ETL_D_TEMPS 
    
-- Carrega els anys i mesos de les ofertes

IS
  hora_inici pfc.logbd.hora_inici%TYPE;

  temps_data_oferta pfc.solicitud.data%TYPE;
  temps_mes_any INTEGER;
  temps_any INTEGER;
  exist_temps integer;
  
     
 CURSOR r_cursor IS
      SELECT DISTINCT(pfc.solicitud.data) AS data_oferta
      FROM pfc.solicitud
      WHERE id_solicitud IN (SELECT id_solicitud FROM pfc.oferta);
                 
BEGIN

  SELECT SYSDATE INTO hora_inici FROM DUAL;

  OPEN r_cursor;
  LOOP
    FETCH r_cursor INTO temps_data_oferta;
    EXIT WHEN r_cursor%NOTFOUND;
    temps_mes_any:=to_number(to_char(temps_data_oferta,'MMYYYY'),'999999');
		temps_any:=to_number(to_char(temps_data_oferta,'YYYY'),'9999');

		SELECT count(*) INTO exist_temps FROM d_temps WHERE mes_any = temps_mes_any;
		IF exist_temps = 0 THEN
			INSERT INTO d_temps ("ID_TEMPS","MES_ANY","ANY") VALUES (s_d_temps.nextval,temps_mes_any,temps_any);
		END IF;
  END LOOP;
  CLOSE r_cursor;

  pfc.sp_i_logbd('sp_etl_d_temps',NULL,hora_inici,sysdate,sqlerrm);

  EXCEPTION
     WHEN NO_DATA_FOUND THEN
       DBMS_OUTPUT.PUT_LINE('Taula origen sense dades');
       pfc.sp_i_logbd('sp_etl_d_temps',NULL,hora_inici,sysdate,sqlerrm);
     WHEN OTHERS THEN 
       DBMS_OUTPUT.PUT_LINE(sqlerrm);
       pfc.sp_i_logbd('sp_etl_d_temps',NULL,hora_inici,sysdate,sqlerrm);
END;
/

--
-- Definition for procedure SP_D_F_OFERTA
--
CREATE OR REPLACE PROCEDURE SP_D_F_OFERTA (
-- Esborra acumulats d'un periode determinat
    p_mes integer,
    p_any integer)

IS

BEGIN
    
  DELETE f_oferta
  WHERE id_temps IN (
    SELECT id_temps 
    FROM d_temps
    WHERE mes_any = to_char(p_mes) || to_char(p_any)
  );

END;
/

--
-- Definition for procedure SP_D_DIMS
--
CREATE OR REPLACE PROCEDURE SP_D_DIMS 
-- Esborra totes les dimensions
    
IS

BEGIN
 
 DELETE d_temps;
 DELETE d_empresa;
 DELETE d_lloc;
 DELETE d_perfil;
 DELETE d_atribut;

END;
/

--
-- Definition for procedure SP_ETL_F_OFERTA
--
CREATE OR REPLACE PROCEDURE SP_ETL_F_OFERTA (
-- Carrega les dades agrupades de les ofertes per totes les dimensions: empresa, perfil, lloc, atribut i temps
    p_mes integer,
    p_any integer,
    p_dims CHAR)
 
IS
  hora_inici pfc.logbd.hora_inici%TYPE;
  id_empresa pfc.persona.id_persona%TYPE;
  nom_empresa pfc.persona.nom_complet%TYPE;
  codi_perfil pfc.perfil.id_perfil%TYPE;
  desc_perfil pfc.perfil.descripcio%TYPE;
  muni_oferta pfc.oferta.municipi%TYPE;
  prov_oferta pfc.oferta.provincia%TYPE;
  pais_oferta pfc.oferta.pais%TYPE;
  atr_experiencia pfc.solicitud.experiencia%TYPE;
  codi_atribut d_atribut.id_atribut%TYPE;
  codi_lloc d_lloc.id_lloc%TYPE;
  codi_temps d_temps.id_temps%TYPE;
  d_provincia d_lloc.provincia%TYPE;
  d_pais d_lloc.pais%TYPE;
  codi_oferta f_oferta.id_oferta%TYPE;
 
  codi_mes_any INTEGER;
  num_ofertes INTEGER;
  num_ofertesIN INTEGER;
  num_ofertesOUT INTEGER;
  salari_mig NUMBER(9,2);
  temps_mig NUMBER(6,2);
  
  
   
 CURSOR r_cursor IS
  SELECT ID_PERSONA,NOM_COMPLET,ID_PERFIL,DESCRIPCIO,EXPERIENCIA,MUNICIPI,PROVINCIA,
          PAIS,to_char(DATA,'MMYYYY') AS mes_any, 
          count(ID_OFERTA) AS NUM_OFERTES, 
          sum(coberta_dins) AS NUM_OFERTES_IN,
          sum(coberta_fora) AS NUM_OFERTES_OUT,
          avg(SALARI) AS SALARI_MIG,
          avg(DATA_OFERTA_COBERTA - DATA) AS TEMPS_MIG
   FROM v_ofertes_dwh 
   WHERE to_char(data,'MM') = p_mes AND
         to_char(data,'YYYY') = p_any
   GROUP BY ID_PERSONA,NOM_COMPLET,ID_PERFIL,DESCRIPCIO,EXPERIENCIA,MUNICIPI,PROVINCIA,
            PAIS, to_char(DATA,'MMYYYY');
  
 
BEGIN

  SELECT SYSDATE INTO hora_inici FROM DUAL;

  sp_d_f_oferta(p_mes,p_any);
  
  IF p_dims = 'D' THEN
    sp_etl_d_empresa;
    sp_etl_d_lloc;
    sp_etl_d_perfil;
    sp_etl_d_temps;
    sp_etl_d_atribut;
  END IF;
   
   
  FOR r_ofertes IN r_cursor LOOP
		id_empresa:=r_ofertes.id_persona;
		codi_perfil:=r_ofertes.id_perfil;
    muni_oferta:=r_ofertes.municipi;
    prov_oferta:=r_ofertes.provincia;
    pais_oferta:=r_ofertes.pais;
    atr_experiencia:=r_ofertes.experiencia;
    codi_mes_any:=r_ofertes.mes_any;
    num_ofertes:=r_ofertes.num_ofertes;
    num_ofertesIN:=r_ofertes.num_ofertes_in;
    num_ofertesOUT:=r_ofertes.num_ofertes_out;
    salari_mig:=r_ofertes.salari_mig;
    temps_mig:=r_ofertes.temps_mig;

    codi_atribut:=0;
    codi_lloc:=0;
    codi_temps:=0;

    SELECT id_atribut INTO codi_atribut FROM d_atribut WHERE experiencia = atr_experiencia;
    SELECT id_lloc INTO codi_lloc FROM d_lloc WHERE municipi = muni_oferta AND provincia = prov_oferta AND pais = pais_oferta;
    SELECT id_temps INTO codi_temps FROM d_temps WHERE mes_any = codi_mes_any;

      
    codi_oferta:=s_f_oferta.nextval;      

    
    INSERT INTO f_oferta ("ID_OFERTA","NUM_OFERTES","NUM_OFERTES_IN","NUM_OFERTES_OUT","SALARI_AVG","TEMPS_AVG","ID_PERFIL","ID_ATRIBUT","ID_EMPRESA","ID_LLOC","ID_TEMPS")
           VALUES (codi_oferta,num_ofertes,num_ofertesIN,num_ofertesOUT,salari_mig,temps_mig,codi_perfil,codi_atribut,id_empresa,codi_lloc,codi_temps);

  END LOOP;
  
  pfc.sp_i_logbd('sp_etl_f_oferta',p_mes || ';' || p_any,hora_inici,sysdate,sqlerrm);
  commit;

  EXCEPTION
     WHEN NO_DATA_FOUND THEN
       DBMS_OUTPUT.PUT_LINE('Taula origen sense dades');
         pfc.sp_i_logbd('sp_etl_f_oferta',p_mes || ';' || p_any,hora_inici,sysdate,sqlerrm);
      ROLLBACK;
     WHEN OTHERS THEN 
       DBMS_OUTPUT.PUT_LINE(sqlerrm);
         pfc.sp_i_logbd('sp_etl_f_oferta',p_mes || ';' || p_any,hora_inici,sysdate,sqlerrm);
      ROLLBACK;
END;
/

--
-- Definition for procedure SP_ETL_DIMS
--
CREATE OR REPLACE PROCEDURE SP_ETL_DIMS 
-- Carrega totes les dimensions
    
IS
 
BEGIN
 
 SP_ETL_D_TEMPS;
 SP_ETL_D_LLOC;
 SP_ETL_D_PERFIL;
 SP_ETL_D_ATRIBUT;
 SP_ETL_D_EMPRESA;

END;
/

--
-- Definition for procedure SP_ETL_F_OFERTA_ALL
--
CREATE OR REPLACE PROCEDURE SP_ETL_F_OFERTA_ALL (
-- Carrega les dades agrupades de les ofertes per totes les dimensions: empresa, perfil, lloc, atribut i temps
    p_mes integer,
    p_any integer)

IS
 
BEGIN
   
  sp_etl_d_atribut;
  sp_etl_d_empresa;
  sp_etl_d_lloc;
  sp_etl_d_perfil;
  sp_etl_d_temps;
  
  -- ESBORREM DADES PRVIES DEL PERODE INDICAT
    
  DELETE f_oferta
  WHERE id_temps IN (
    SELECT id_temps 
    FROM d_temps
    WHERE mes_any = to_char(p_mes) || to_char(p_any)
  );

  sp_etl_f_oferta(p_mes,p_any);
END;
/
